@@ -1,4 +1,7 @@
-function EntityCollectionFromIds(gameState, idList){
+var AEGIS = function(m)
+{
+
+m.EntityCollectionFromIds = function(gameState, idList){
 	var ents = {};
 	for (var i in idList){
 		var id = idList[i];
@@ -6,5 +9,8 @@ function EntityCollectionFromIds(gameState, idList){
 			ents[id] = gameState.entities._entities[id];
 		}
 	}
-	return new EntityCollection(gameState.sharedScript, ents);
+	return new API3.EntityCollection(gameState.sharedScript, ents);
 }
+
+return m;
+}(AEGIS);
