@@ -1,15 +1,18 @@
+var AEGIS = function(m)
+{
+
 /**
  * This class makes a worker do as instructed by the economy manager
  */
 
-var Worker = function(ent) {
+m.Worker = function(ent) {
 	this.ent = ent;
 	this.maxApproachTime = 45000;
 	this.unsatisfactoryResource = false;	// if true we'll reguarly check if we can't have better now.
 	this.baseID = 0;
 };
 
-Worker.prototype.update = function(baseManager, gameState) {
+m.Worker.prototype.update = function(baseManager, gameState) {
 	this.baseID = baseManager.ID;
 	var subrole = this.ent.getMetadata(PlayerID, "subrole");
 
@@ -93,9 +96,9 @@ Worker.prototype.update = function(baseManager, gameState) {
 					&& this.ent.unitAIOrderData()[0]["target"])
 				{
 					var ent = gameState.getEntityById(this.ent.unitAIOrderData()[0]["target"]);
-					debug ("here " + this.startApproachingResourceAmount + "," + ent.resourceSupplyAmount());
+					m.debug ("here " + this.startApproachingResourceAmount + "," + ent.resourceSupplyAmount());
 					if (ent && this.startApproachingResourceAmount == ent.resourceSupplyAmount() && this.startEnt == ent.id()) {
-						debug (ent.toString() + " is inaccessible");
+						m.debug (ent.toString() + " is inaccessible");
 						ent.setMetadata(PlayerID, "inaccessible", true);
 						this.ent.flee(ent);
 						this.ent.setMetadata(PlayerID, "subrole", "idle");
@@ -116,7 +119,7 @@ Worker.prototype.update = function(baseManager, gameState) {
 					var ent = gameState.getEntityById(this.gatheringFrom);
 					if ((ent && ent.resourceSupplyAmount() == ent.resourceSupplyMax())) {
 						// if someone gathers from it, it's only that the pathfinder sucks.
-						debug (ent.toString() + " is inaccessible");
+						m.debug (ent.toString() + " is inaccessible");
 						ent.setMetadata(PlayerID, "inaccessible", true);
 						this.ent.flee(ent);
 						this.ent.setMetadata(PlayerID, "subrole", "idle");
@@ -129,7 +132,7 @@ Worker.prototype.update = function(baseManager, gameState) {
 				var ent = gameState.getEntityById(this.ent.unitAIOrderData()[0].target);
 				if (ent && !ent.isHurt()) {
 					// if someone gathers from it, it's only that the pathfinder sucks.
-					debug (ent.toString() + " is inaccessible from Combat");
+					m.debug (ent.toString() + " is inaccessible from Combat");
 					ent.setMetadata(PlayerID, "inaccessible", true);
 					this.ent.flee(ent);
 					this.ent.setMetadata(PlayerID, "subrole", "idle");
@@ -140,9 +143,9 @@ Worker.prototype.update = function(baseManager, gameState) {
 	} else if(subrole === "builder") {
 		
 		// check for transport.
-		if (gameState.ai.playedTurn % 5 === 0)
+		/*if (gameState.ai.playedTurn % 5 === 0)
 		{
-			if (this.ent.unitAIOrderData().length && this.ent.unitAIState().split(".")[2] === "APPROACHING" && this.ent.unitAIOrderData()[0]["target"])
+			if (this.ent.unitAIOrderData().length && this.ent.unitAIState().split(".")[2] && this.ent.unitAIState().split(".")[2] === "APPROACHING" && this.ent.unitAIOrderData()[0]["target"])
 			{
 				var ress = gameState.getEntityById(this.ent.unitAIOrderData()[0]["target"]);
 				if (ress !== undefined)
@@ -151,12 +154,11 @@ Worker.prototype.update = function(baseManager, gameState) {
 					var mIndex = gameState.ai.accessibility.getAccessValue(this.ent.position());
 					if (index !== mIndex && index !== 1)
 					{
-						//gameState.ai.HQ.navalManager.askForTransport(this.ent.id(), this.ent.position(), ress.position());
+						gameState.ai.HQ.navalManager.askForTransport(this.ent.id(), this.ent.position(), ress.position());
 					}
 				}
 			}
-		}
-
+		}*/
 		
 		if (this.ent.unitAIState().split(".")[1] !== "REPAIR") {
 			var target = gameState.getEntityById(this.ent.getMetadata(PlayerID, "target-foundation"));
@@ -166,8 +168,7 @@ Worker.prototype.update = function(baseManager, gameState) {
 			{
 				if (!this.ent.getMetadata(PlayerID, "keepSubrole"))
 					this.ent.setMetadata(PlayerID, "subrole", "idle");
-			}
-			else
+			} else
 				this.ent.repair(target);
 		}
 		this.startApproachingResourceTime = gameState.getTimeElapsed();
@@ -186,7 +187,7 @@ Worker.prototype.update = function(baseManager, gameState) {
 // this can happen in two ways:
 //		-either we were on an unsatisfactory resource last time we started gathering (this.unsatisfactoryResource)
 //		-Or we auto-moved to a bad resource thanks to the great UnitAI.
-Worker.prototype.checkUnsatisfactoryResource = function(gameState) {
+m.Worker.prototype.checkUnsatisfactoryResource = function(gameState) {
 	if (this.unsatisfactoryResource)
 		return true;
 	if (this.ent.unitAIOrderData().length && this.ent.unitAIState().split(".")[1] === "GATHER" && this.ent.unitAIState().split(".")[2] === "GATHERING" && this.ent.unitAIOrderData()[0]["target"])
@@ -198,162 +199,192 @@ Worker.prototype.checkUnsatisfactoryResource = function(gameState) {
 	return false;
 };
 
-Worker.prototype.startGathering = function(baseManager, gameState) {
+m.Worker.prototype.startGathering = function(baseManager, gameState) {
 	var resource = this.ent.getMetadata(PlayerID, "gather-type");
 	var ent = this.ent;
 	var self = this;
 	
-	if (!ent.position()){
+	if (!ent.position()) {
 		// TODO: work out what to do when entity has no position
 		return;
 	}
 	
-	// TODO: this is not necessarily optimal.
-	
-	// find closest dropsite which has nearby resources of the correct type
-	var minDropsiteDist = Math.min(); // set to infinity initially
-	var nearestResources = undefined;
-	var nearestDropsite = undefined;
-	
-	// first step: count how many dropsites we have that have enough resources "close" to them.
-	// TODO: this is a huge part of multi-base support. Count only those in the same base as the worker.
-	var number = 0;
-	
-	var ourDropsites = EntityCollectionFromIds(gameState,Object.keys(baseManager.dropsites));
-	if (ourDropsites.length === 0)
+	/* Procedure for gathering resources
+	 * Basically the AI focuses a lot on dropsites, and we will too
+	 * So what we want is trying to find the best dropsites
+	 * Traits: it needs to have a lot of resources available
+	 *	-it needs to have room available for me
+	 *  -it needs to be as close as possible (meaning base)
+	 * Once we've found the best dropsite, we'll just pick a random close resource.
+	 * TODO: we probably could pick something better. 
+	 */
+
+	var wantedDropsite = 0;
+	var wantedDropsiteCoeff = 0;
+
+	var forceFaraway = false;
+
+	// So for now what I'll do is that I'll check dropsites in my base, then in other bases.
+
+	for (var id in baseManager.dropsites)
 	{
-		debug ("We do not have a dropsite for " + resource + ", aborting");
-		return;
+		var dropsiteInfo = baseManager.dropsites[id][resource];
+		var capacity = baseManager.getDpWorkerCapacity(gameState, id, resource);
+		if (capacity === undefined)	// presumably we're not ready
+			continue;
+		if (dropsiteInfo)
+		{
+			var coeff = dropsiteInfo[3] + (capacity-dropsiteInfo[5].length)*1000;
+			if (gameState.getEntityById(id).hasClass("CivilCentre"))
+				coeff += 20000;
+			if (coeff > wantedDropsiteCoeff)
+			{
+				wantedDropsiteCoeff = coeff;
+				wantedDropsite = id;
+			}
+		}
 	}
-	
-	var maxPerDP = 20;
-	if (resource === "food")
-		maxPerDP = 200;
-	
-	ourDropsites.forEach(function (dropsite) {
-		if (baseManager.dropsites[dropsite.id()][resource] && baseManager.dropsites[dropsite.id()][resource][4] > 1000
-			&& baseManager.dropsites[dropsite.id()][resource][5].length < maxPerDP)
-			number++;
-	});
-	
-	// Allright second step, if there are any such dropsites, we pick the closest.
-	// we pick one with a lot of resource, or we pick the only one available (if it's high enough, otherwise we'll see with "far" below).
-	if (number > 0)
+
+	if (wantedDropsite === 0)
 	{
-		ourDropsites.forEach(function (dropsite) { //}){
-			if (baseManager.dropsites[dropsite.id()][resource] === undefined)
-				return;
-			if (dropsite.position() && (baseManager.dropsites[dropsite.id()][resource][4] > 1000 || (number === 1 && baseManager.dropsites[dropsite.id()][resource][4] > 200) )
-				&& baseManager.dropsites[dropsite.id()][resource][5].length < maxPerDP) {
-				var dist = SquareVectorDistance(ent.position(), dropsite.position());
-				if (dist < minDropsiteDist){
-					minDropsiteDist = dist;
-					nearestResources = baseManager.dropsites[dropsite.id()][resource][1];
-					nearestDropsite = dropsite;
+		for (var id in baseManager.dropsites)
+		{
+			var dropsiteInfo = baseManager.dropsites[id][resource];
+			var capacity = baseManager.getDpWorkerCapacity(gameState, id, resource, true);
+			if (capacity === undefined)	// presumably we're not ready
+				continue;
+			if (dropsiteInfo)
+			{
+				var coeff = dropsiteInfo[4] + (capacity-dropsiteInfo[5].length)*100;
+				if (coeff > wantedDropsiteCoeff)
+				{
+					wantedDropsiteCoeff = coeff;
+					wantedDropsite = id;
+					forceFaraway = true;
 				}
 			}
-		});
+		}
 	}
-	// we've found no fitting dropsites close enough from us.
-	// So'll try with far away.
-	if (!nearestResources || nearestResources.length === 0) {
-		ourDropsites.forEach(function (dropsite) { //}){
-			if (baseManager.dropsites[dropsite.id()][resource] === undefined)
-				return;
-			if (dropsite.position() && baseManager.dropsites[dropsite.id()][resource][4] > 400
-				&& baseManager.dropsites[dropsite.id()][resource][5].length < maxPerDP) {
-				var dist = SquareVectorDistance(ent.position(), dropsite.position());
-				if (dist < minDropsiteDist){
-					minDropsiteDist = dist;
-					nearestResources = baseManager.dropsites[dropsite.id()][resource][1];
-					nearestDropsite = dropsite;
+	// so if we're here we have checked our whole base for a proper dropsite.
+	// for food, try to build fields if there are any.
+	if (wantedDropsiteCoeff < 200 && resource === "food" && this.buildAnyField(gameState))
+		return;
+
+	// haven't found any, check in other bases
+	// TODO: we should pick closest/most accessible bases first.
+	if (wantedDropsiteCoeff < 200)
+	{
+		for each (var base in gameState.ai.HQ.baseManagers)
+		{
+			// TODO: check we can access that base, and/or pick the best base.
+			if (base.ID === this.baseID || wantedDropsite !== 0)
+				continue;
+			for (var id in base.dropsites)
+			{
+				// if we have at least 1000 resources (including faraway) on this d
+				var dropsiteInfo = base.dropsites[id][resource];
+				var capacity = base.getDpWorkerCapacity(gameState, id, resource);
+				if (capacity === undefined)	// presumably we're not ready
+					continue;
+				if (dropsiteInfo && dropsiteInfo[3] > 600 && dropsiteInfo[5].length < capacity)
+				{
+					// we want to change bases.
+					this.ent.setMetadata(PlayerID,"base",base.ID);
+					wantedDropsite = id;
+					break;
 				}
 			}
-		});
-	}
-
-	if (!nearestResources || nearestResources.length === 0){
-		if (resource === "food")
-			if (this.buildAnyField(gameState))
-				return;
-
-		if (this.unsatisfactoryResource == true)
-			return;	// we were already not satisfied, we're still not, change not.
-
-		if (gameState.ai.HQ.switchWorkerBase(gameState, this.ent, resource))
-			return;
-
-		//debug ("No fitting dropsite for " + resource + " found, iterating the map.");
-		nearestResources = gameState.getResourceSupplies(resource);
-		this.unsatisfactoryResource = true;
-		// TODO: should try setting up dropsites.
-	} else {
-		this.unsatisfactoryResource = false;
+		}
 	}
 	
-	if (nearestResources.length === 0){
-		if (resource === "food")
+	// I know, this is horrible code repetition.
+	// TODO: avoid horrible code repetition
+
+	// haven't found any, check in other bases
+	// TODO: we should pick closest/most accessible bases first.
+	if (wantedDropsiteCoeff < 200)
+	{
+		for each (var base in gameState.ai.HQ.baseManagers)
 		{
-			if (this.buildAnyField(gameState))
-				return;
-			if (gameState.ai.HQ.switchWorkerBase(gameState, this.ent, resource))
-				return;
-			debug("No " + resource + " found! (1)");
+			if (base.ID === this.baseID || wantedDropsite !== 0)
+				continue;
+			for (var id in base.dropsites)
+			{
+				// if we have at least 1000 resources (including faraway) on this d
+				var dropsiteInfo = base.dropsites[id][resource];
+				var capacity = baseManager.getDpWorkerCapacity(gameState, id, resource, true);
+				if (capacity === undefined)	// presumably we're not ready
+					continue;
+				if (dropsiteInfo && dropsiteInfo[4] > 600 && dropsiteInfo[5].length < capacity)
+				{
+					this.ent.setMetadata(PlayerID,"base",base.ID);
+					wantedDropsite = id;
+					break;	// here I'll break, TODO.
+				}
+			}
 		}
-		else
-		{
-			if (gameState.ai.HQ.switchWorkerBase(gameState, this.ent, resource))
-				return;
-			debug("No " + resource + " found! (1)");
-		}
-		return;
 	}
-	//debug("Found " + nearestResources.length + "spots for " + resource);
-	
-	/*if (!nearestDropsite) {
-		debug ("No dropsite for " +resource);
+
+	if (wantedDropsite === 0)
+	{
+		//TODO: something.
+		// Okay so we haven't found any appropriate dropsite anywhere.
+		m.debug("No proper dropsite found for " + resource + ", waiting.");
 		return;
-	}*/
-	
-	var supplies = [];
-	var nearestSupplyDist = Math.min();
-	var nearestSupply = undefined;
-	
-	// filter resources
-	// TODo: add a bonus for resources with a lot of resources left, perhaps, to spread gathering?
-	nearestResources.forEach(function(supply) { //}){
-		// sanity check, perhaps sheep could be garrisoned?
-		if (!supply.position()) {
-			//debug ("noposition");
-			return;
-		}
-		
-		if (supply.getMetadata(PlayerID, "inaccessible") === true) {
-			//debug ("inaccessible");
-			return;
-		}
+	} else
+		this.pickResourceNearDropsite(gameState, resource, wantedDropsite, forceFaraway);
+};
 
-		if (supply.isFull() === true
-			|| (gameState.turnCache["ressGathererNB"] && gameState.turnCache["ressGathererNB"][supply.id()]
-				&& gameState.turnCache["ressGathererNB"][supply.id()] + supply.resourceSupplyGatherers().length >= supply.maxGatherers))
+
+m.Worker.prototype.pickResourceNearDropsite = function(gameState, resource, dropsiteID, forceFaraway)
+{
+	// get the entity.
+	var dropsite = gameState.getEntityById(dropsiteID);
+	
+	if (!dropsite)
+		return false;
+
+	// get the dropsite info
+	var baseManager = this.ent.getMetadata(PlayerID,"base");
+	baseManager = gameState.ai.HQ.baseManagers[baseManager];
+
+	var dropsiteInfo = baseManager.dropsites[dropsiteID][resource];
+	if (!dropsiteInfo)
+		return false;
+
+	var faraway = (forceFaraway === true) ? true : false;
+
+	var capacity = baseManager.getDpWorkerCapacity(gameState, dropsiteID, resource, faraway);
+	if (dropsiteInfo[5].length >= capacity || dropsiteInfo[3] < 200)
+		faraway = true;
+
+	var resources = (faraway === true) ? dropsiteInfo[1] : dropsiteInfo[0];
+
+	var wantedSupply = 0;
+	var wantedSupplyCoeff = Math.min();
+	
+	// Pick the best resource
+	resources.forEach(function(supply) {
+		if (!supply.position())
+			return;
+		
+		if (supply.getMetadata(PlayerID, "inaccessible") === true)
 			return;
 
-							 
-		// Don't gather enemy farms or farms from another base
-		if ((!supply.isOwn(PlayerID) && supply.owner() !== 0) || (supply.isOwn(PlayerID) && supply.getMetadata(PlayerID,"base") !== self.baseID)) {
-			//debug ("enemy");
+		if (m.IsSupplyFull(gameState, supply) === true)
 			return;
-		}
 		
-		// quickscope accessbility check.
-		if (!gameState.ai.accessibility.pathAvailable(gameState, ent.position(), supply.position())) {
-			//debug ("nopath");
+		// TODO: make a quick accessibility check for sanity
+/*		if (!gameState.ai.accessibility.pathAvailable(gameState, ent.position(), supply.position())) {
+			//m.debug ("nopath");
 			return;
-		}
+		}*/
+
 		// some simple check for chickens: if they're in a square that's inaccessible, we won't gather from them.
+		// TODO: make sure this works with rounding.
 		if (supply.footprintRadius() < 1)
 		{
-			var fakeMap = new Map(gameState.sharedScript,gameState.getMap().data);
+			var fakeMap = new API3.Map(gameState.sharedScript,gameState.getMap().data);
 			var id = fakeMap.gamePosToMapPos(supply.position())[0] + fakeMap.width*fakeMap.gamePosToMapPos(supply.position())[1];
 			if ( (gameState.sharedScript.passabilityClasses["pathfinderObstruction"] & gameState.getMap().data[id]) )
 			{
@@ -362,101 +393,50 @@ Worker.prototype.startGathering = function(baseManager, gameState) {
 			}
 		}
 
-		// measure the distance to the resource (largely irrelevant)
-		 var dist = SquareVectorDistance(supply.position(), ent.position());
-							 
-		if (dist > 4900 && supply.hasClass("Animal"))
-		return;
-
-		// Add on a factor for the nearest dropsite if one exists
-		if (nearestDropsite !== undefined ){
-			dist += 4*SquareVectorDistance(supply.position(), nearestDropsite.position());
-			dist /= 5.0;
-		}
-					
-		var territoryOwner = Map.createTerritoryMap(gameState).getOwner(supply.position());
+		// Factor in distance to the dropsite.
+		var dist = API3.SquareVectorDistance(supply.position(), dropsite.position());
+				
+		var territoryOwner = m.createTerritoryMap(gameState).getOwner(supply.position());
 		if (territoryOwner != PlayerID && territoryOwner != 0) {
 			dist *= 5.0;
-			//return;
 		} else if (dist < 40000 && supply.resourceSupplyType().generic == "treasure"){
 			// go for treasures if they're not in enemy territory
 			dist /= 1000;
 		}
 
-		if (dist < nearestSupplyDist) {
-			nearestSupplyDist = dist;
-			nearestSupply = supply;
-		} 
+		if (dist < wantedSupplyCoeff) {
+			wantedSupplyCoeff = dist;
+			wantedSupply = supply;
+		}
 	});
-	if (nearestSupply) {
-		var pos = nearestSupply.position();
-		
-		// find a fitting dropsites in case we haven't already.
-		if (!nearestDropsite) {
-			ourDropsites.forEach(function (dropsite){ //}){
-				if (dropsite.position()){
-					var dist = SquareVectorDistance(pos, dropsite.position());
-					if (dist < minDropsiteDist){
-						minDropsiteDist = dist;
-						nearestDropsite = dropsite;
-					}
-				}
-			});
-			if (!nearestDropsite)
-			{
-				debug ("No dropsite for " +resource);
-				return;
-			}
-		}
-
-		// if the resource is far away, try to build a farm instead.
-		var tried = false;
-		if (resource === "food" && SquareVectorDistance(pos,this.ent.position()) > 22500)
-		{
-			tried = this.buildAnyField(gameState);
-			if (!tried && SquareVectorDistance(pos,this.ent.position()) > 62500) {
-				// TODO: ought to change behavior here.
-				return; // wait. a farm should appear.
-			}
-		}
-		if (!tried) {
-			if (!gameState.turnCache["ressGathererNB"])
-			{
-				gameState.turnCache["ressGathererNB"] = {};
-				gameState.turnCache["ressGathererNB"][nearestSupply.id()] = 1;
-			} else if (!gameState.turnCache["ressGathererNB"][nearestSupply.id()])
-				gameState.turnCache["ressGathererNB"][nearestSupply.id()] = 1;
-			else
-				gameState.turnCache["ressGathererNB"][nearestSupply.id()]++;
-			
-			this.maxApproachTime = Math.max(30000, VectorDistance(pos,this.ent.position()) * 5000);
-			this.startApproachingResourceAmount = ent.resourceSupplyAmount();
-			this.startEnt = ent.id();
-			ent.gather(nearestSupply);
-			ent.setMetadata(PlayerID, "target-foundation", undefined);
-		}
-	} else {
+	
+	if (!wantedSupply)
+	{
 		if (resource === "food" && this.buildAnyField(gameState))
-			return;
+			return true;
 
-		if (gameState.ai.HQ.switchWorkerBase(gameState, this.ent, resource))
-			return;
-		
-		if (resource !== "food")
-			debug("No " + resource + " found! (2)");
-		// If we had a fitting closest dropsite with a lot of resources, mark it as not good. It means it's probably full. Then retry.
-		// it'll be resetted next time it's counted anyway.
-		if (nearestDropsite && nearestDropsite.getMetadata(PlayerID, "resource-quantity-" +resource)+nearestDropsite.getMetadata(PlayerID, "resource-quantity-far-" +resource) > 400)
-		{
-			nearestDropsite.setMetadata(PlayerID, "resource-quantity-" +resource, 0);
-			nearestDropsite.setMetadata(PlayerID, "resource-quantity-far-" +resource, 0);
-			this.startGathering(baseManager, gameState);
-		}
+		//m.debug("Found a proper dropsite for " + resource + " but apparently no resources are available.");
+		return false;
 	}
+
+	var pos = wantedSupply.position();
+		
+	// add the worker to the turn cache
+	m.AddTCGatherer(gameState,wantedSupply.id());
+	// helper to check if it's accessible.
+	this.maxApproachTime = Math.max(30000, API3.VectorDistance(pos,this.ent.position()) * 5000);
+	this.startApproachingResourceAmount = wantedSupply.resourceSupplyAmount();
+	// helper for unsatisfactory resource.
+	this.startEnt = wantedSupply.id();
+	this.ent.gather(wantedSupply);
+	// sanity.
+	this.ent.setMetadata(PlayerID, "linked-to-dropsite", dropsiteID);
+	this.ent.setMetadata(PlayerID, "target-foundation", undefined);
+	return true;
 };
 
 // Makes the worker deposit the currently carried resources at the closest dropsite
-Worker.prototype.returnResources = function(gameState){
+m.Worker.prototype.returnResources = function(gameState){
 	if (!this.ent.resourceCarrying() || this.ent.resourceCarrying().length === 0){
 		return true;	// assume we're OK.
 	}
@@ -472,7 +452,7 @@ Worker.prototype.returnResources = function(gameState){
 	var dist = Math.min();
 	gameState.getOwnDropsites(resource).forEach(function(dropsite){
 		if (dropsite.position()){
-			var d = SquareVectorDistance(self.ent.position(), dropsite.position());
+			var d = API3.SquareVectorDistance(self.ent.position(), dropsite.position());
 			if (d < dist){
 				dist = d;
 				closestDropsite = dropsite;
@@ -481,7 +461,7 @@ Worker.prototype.returnResources = function(gameState){
 	});
 	
 	if (!closestDropsite){
-		debug("No dropsite found to deposit " + resource);
+		m.debug("No dropsite found to deposit " + resource);
 		return false;
 	}
 	
@@ -489,7 +469,7 @@ Worker.prototype.returnResources = function(gameState){
 	return true;
 };
 
-Worker.prototype.startHunting = function(gameState, baseManager){
+m.Worker.prototype.startHunting = function(gameState, baseManager){
 	var ent = this.ent;
 	
 	if (!ent.position() || !baseManager.isHunting)
@@ -500,7 +480,7 @@ Worker.prototype.startHunting = function(gameState, baseManager){
 	var resources = gameState.getResourceSupplies("food");
 	
 	if (resources.length === 0){
-		debug("No food found to hunt!");
+		m.debug("No food found to hunt!");
 		return;
 	}
 	
@@ -522,9 +502,9 @@ Worker.prototype.startHunting = function(gameState, baseManager){
 			return;
 					  
 		// measure the distance to the resource
-		var dist = SquareVectorDistance(supply.position(), ent.position());
+		var dist = API3.SquareVectorDistance(supply.position(), ent.position());
 
-		var territoryOwner = Map.createTerritoryMap(gameState).getOwner(supply.position());
+		var territoryOwner = m.createTerritoryMap(gameState).getOwner(supply.position());
 		if (territoryOwner != PlayerID && territoryOwner != 0) {
 			dist *= 3.0;
 		}
@@ -547,7 +527,7 @@ Worker.prototype.startHunting = function(gameState, baseManager){
 		// find a fitting dropsites in case we haven't already.
 		gameState.getOwnDropsites("food").forEach(function (dropsite){ //}){
 			if (dropsite.position()){
-				var dist = SquareVectorDistance(pos, dropsite.position());
+				var dist = API3.SquareVectorDistance(pos, dropsite.position());
 				if (dist < minDropsiteDist){
 					minDropsiteDist = dist;
 					nearestDropsite = dropsite;
@@ -558,7 +538,7 @@ Worker.prototype.startHunting = function(gameState, baseManager){
 		{
 			baseManager.isHunting = false;
 			ent.setMetadata(PlayerID, "role", undefined);
-			debug ("No dropsite for hunting food");
+			m.debug ("No dropsite for hunting food");
 			return;
 		}
 		if (minDropsiteDist > 35000) {
@@ -571,11 +551,11 @@ Worker.prototype.startHunting = function(gameState, baseManager){
 	} else {
 		baseManager.isHunting = false;
 		ent.setMetadata(PlayerID, "role", undefined);
-		debug("No food found for hunting! (2)");
+		m.debug("No food found for hunting! (2)");
 	}
 };
 
-Worker.prototype.getResourceType = function(type){
+m.Worker.prototype.getResourceType = function(type){
 	if (!type || !type.generic){
 		return undefined;
 	}
@@ -587,7 +567,7 @@ Worker.prototype.getResourceType = function(type){
 	}
 };
 
-Worker.prototype.getGatherRate = function(gameState) {
+m.Worker.prototype.getGatherRate = function(gameState) {
 	if (this.ent.getMetadata(PlayerID,"subrole") !== "gatherer")
 		return 0;
 	var rates = this.ent.resourceGatherRates();
@@ -601,7 +581,7 @@ Worker.prototype.getGatherRate = function(gameState) {
 		if (type.generic == "treasure")
 			return 1000;
 		var tstring = type.generic + "." + type.specific;
-		//debug (+rates[tstring] + " for " + tstring + " for " + this.ent._templateName);
+		//m.debug (+rates[tstring] + " for " + tstring + " for " + this.ent._templateName);
 		if (rates[tstring])
 			return rates[tstring];
 		return 0;
@@ -609,30 +589,55 @@ Worker.prototype.getGatherRate = function(gameState) {
 	return 0;
 };
 
-Worker.prototype.buildAnyField = function(gameState){
+m.Worker.prototype.buildAnyField = function(gameState){
 	var self = this;
-	var okay = false;
-	var foundations = gameState.getOwnFoundations().filter(Filters.byMetadata(PlayerID,"base",this.baseID));
-	foundations.filterNearest(this.ent.position(), foundations.length);
-	foundations.forEach(function (found) {
-		if (found._template.BuildRestrictions.Category === "Field" && !okay) {
-			self.ent.repair(found);
-			okay = true;
-			return;
+	var foundations = gameState.getOwnFoundations();
+	var baseFoundations = foundations.filter(API3.Filters.byMetadata(PlayerID,"base",this.baseID));
+	
+	var maxGatherers = gameState.getTemplate(gameState.applyCiv("structures/{civ}_field")).maxGatherers();
+
+	var bestFarmEnt = undefined;
+	var bestFarmCoeff = 10000000;
+	baseFoundations.forEach(function (found) {
+		if (found.hasClass("Field")) {
+			var coeff = API3.SquareVectorDistance(found.position(), self.ent.position());
+			if (found.getBuildersNb() && found.getBuildersNb() >= maxGatherers)
+				return;
+			if (coeff <= bestFarmCoeff)
+			{
+				bestFarmEnt = found;
+				bestFarmCoeff = coeff;
+			}
 		}
 	});
-	if (!okay)
+	if (bestFarmEnt !== undefined)
 	{
-		var foundations = gameState.getOwnFoundations();
-		foundations.filterNearest(this.ent.position(), foundations.length);
-		foundations.forEach(function (found) {
-			if (found._template.BuildRestrictions.Category === "Field" && !okay) {
-				self.ent.repair(found);
-				self.ent.setMetadata(PlayerID,"base", found.getMetadata(PlayerID,"base"));
-				okay = true;
-				return;
-			}
-		});
+		self.ent.repair(bestFarmEnt);
+		return true;
 	}
-	return okay;
+	foundations.forEach(function (found) {
+		if (found.hasClass("Field")) {
+			var coeff = API3.SquareVectorDistance(found.position(), self.ent.position());
+			if (found.getBuildersNb() && found.getBuildersNb() >= found.maxGatherers())
+				return;
+			if (coeff <= bestFarmCoeff)
+			{
+				bestFarmEnt = found;
+				bestFarmCoeff = coeff;
+			}
+		}
+	});
+	if (bestFarmEnt !== undefined)
+	{
+		self.ent.repair(bestFarmEnt);
+		self.ent.setMetadata(PlayerID,"base", bestFarmEnt.getMetadata(PlayerID,"base"));
+		this.startEnt = bestFarmEnt.id();
+		self.ent.gather(bestFarmEnt,true);
+		self.ent.setMetadata(PlayerID, "target-foundation", undefined);
+		return true;
+	}
+	return false;
 };
+
+return m;
+}(AEGIS);
