@@ -9,15 +9,16 @@
 function loadCivData()
 {	// Load all JSON files containing civ data
 	var civData = {};
-	var civFiles = buildDirEntList("civs/", "*.json", false);
+	var civFiles = Engine.BuildDirEntList("civs/", "*.json", false);
 	
 	for each (var filename in civFiles)
 	{	// Parse data if valid file
 		var data = parseJSONData(filename);
+		translateObjectKeys(data, ["Name", "Description", "History", "Special"]);
 		civData[data.Code] = data;
 	}
 	
 	return civData;
 }
 
-// ====================================================================
\ No newline at end of file
+// ====================================================================
