@@ -24,6 +24,33 @@ EndGameManager.prototype.Init = function()
 EndGameManager.prototype.SetGameType = function(newGameType)
 {
 	this.gameType = newGameType;
+	Engine.BroadcastMessage(MT_GameTypeChanged, {});
+};
+
+EndGameManager.prototype.CheckGameType = function(type)
+{
+	return this.gameType == type;
+};
+
+EndGameManager.prototype.MarkPlayerAsWon = function(playerID)
+{
+	var cmpPlayerManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_PlayerManager);
+	var numPlayers = cmpPlayerManager.GetNumPlayers();
+	for (var i = 1; i < numPlayers; i++)
+	{
+		var playerEntityId = cmpPlayerManager.GetPlayerByID(i);
+		var cmpPlayer = Engine.QueryInterface(playerEntityId, IID_Player);
+		if (cmpPlayer.GetState() != "active")
+			continue;
+		if (playerID == cmpPlayer.GetPlayerID() || this.alliedVictory && cmpPlayer.IsMutualAlly(playerID))
+			cmpPlayer.SetState("won")
+		else
+			Engine.PostMessage(playerEntityId, MT_PlayerDefeated, { "playerId": i } );
+	}
+
+	// Reveal the map to all players
+	var cmpRangeManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_RangeManager);
+	cmpRangeManager.SetLosRevealAll(-1, true);
 };
 
 EndGameManager.prototype.SetAlliedVictory = function(flag)
@@ -34,19 +61,19 @@ EndGameManager.prototype.SetAlliedVictory = function(flag)
 /*
  * Check players the next turn. Avoids problems in Atlas, with promoting entities etc
  */
-EndGameManager.prototype.CheckPlayers = function()
+EndGameManager.prototype.CheckConquestCriticalEntities = function()
 {
 	if (this.timeout)
 		return;
 	// wait a turn for actually checking the players
 	var cmpTimer = Engine.QueryInterface(SYSTEM_ENTITY, IID_Timer);
-	this.timeout = cmpTimer.SetTimeout(this.entity, IID_EndGameManager, "CheckPlayersNow", 100, null);	
+	this.timeout = cmpTimer.SetTimeout(this.entity, IID_EndGameManager, "CheckConquestCriticalEntitiesNow", 100, null);	
 };
 
 /*
  * Check players immediately. Might cause problems with converting/promoting entities.
  */
-EndGameManager.prototype.CheckPlayersNow = function()
+EndGameManager.prototype.CheckConquestCriticalEntitiesNow = function()
 {
 	if (this.timeout)
 		this.timeout = null;
