@@ -22,6 +22,9 @@ GuiInterface.prototype.Init = function()
 	this.placementWallLastAngle = 0;
 	this.notifications = [];
 	this.renamedEntities = [];
+	this.timeNotificationID = 1;
+	this.timeNotifications = [];
+	this.entsRallyPointsDisplayed = [];
 };
 
 /*
@@ -94,7 +97,7 @@ GuiInterface.prototype.GetSimulationState = function(player)
 			"isEnemy": enemies,
 			"entityLimits": cmpPlayerEntityLimits.GetLimits(),
 			"entityCounts": cmpPlayerEntityLimits.GetCounts(),
-			"techModifications": cmpTechnologyManager.GetTechModifications(),
+			"entityLimitChangers": cmpPlayerEntityLimits.GetLimitChangers(),
 			"researchQueued": cmpTechnologyManager.GetQueuedResearch(),
 			"researchStarted": cmpTechnologyManager.GetStartedResearch(),
 			"researchedTechs": cmpTechnologyManager.GetResearchedTechs(),
@@ -132,6 +135,10 @@ GuiInterface.prototype.GetExtendedSimulationState = function(player)
 		ret.players[i].statistics = cmpPlayerStatisticsTracker.GetStatistics();
 	}
 
+	// Add bartering prices
+	var cmpBarter = Engine.QueryInterface(SYSTEM_ENTITY, IID_Barter);
+	ret.barterPrices = cmpBarter.GetPrices();
+
 	return ret;
 };
 
@@ -159,7 +166,24 @@ GuiInterface.prototype.GetEntityState = function(player, ent)
 
 	var ret = {
 		"id": ent,
-		"template": template
+		"template": template,
+
+		"alertRaiser": null,
+		"buildEntities": null,
+		"identity": null,
+		"foundation": null,
+		"garrisonHolder": null,
+		"gate": null,
+		"guard": null,
+		"pack": null,
+		"player": -1,
+		"position": null,
+		"production": null,
+		"rallyPoint": null,
+		"rotation": null,
+		"trader": null,
+		"unitAI": null,
+		"visibility": null,
 	};
 
 	var cmpIdentity = Engine.QueryInterface(ent, IID_Identity);
@@ -218,7 +242,7 @@ GuiInterface.prototype.GetEntityState = function(player, ent)
 	{
 		ret.trader = {
 			"goods": cmpTrader.GetGoods(),
-			"preferredGoods": cmpTrader.GetPreferredGoods()
+			"requiredGoods": cmpTrader.GetRequiredGoods()
 		};
 	}
 
@@ -265,7 +289,7 @@ GuiInterface.prototype.GetEntityState = function(player, ent)
 			"isGuarding": cmpUnitAI.IsGuardOf(),
 		};
 		// Add some information needed for ungarrisoning
-		if (cmpUnitAI.isGarrisoned && ret.player !== undefined)
+		if (cmpUnitAI.IsGarrisoned() && ret.player !== undefined)
 			ret.template = "p" + ret.player + "&" + ret.template;
 	}
 
@@ -285,6 +309,16 @@ GuiInterface.prototype.GetEntityState = function(player, ent)
 		};
 	}
 
+	var cmpAlertRaiser = Engine.QueryInterface(ent, IID_AlertRaiser);
+	if (cmpAlertRaiser)
+	{
+		ret.alertRaiser = {
+			"level": cmpAlertRaiser.GetLevel(),
+			"canIncreaseLevel": cmpAlertRaiser.CanIncreaseLevel(),
+			"hasRaisedAlert": cmpAlertRaiser.HasRaisedAlert(),
+		};
+	}
+
 	var cmpRangeManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_RangeManager);
 	ret.visibility = cmpRangeManager.GetLosVisibility(ent, player, false);
 
@@ -296,7 +330,19 @@ GuiInterface.prototype.GetEntityState = function(player, ent)
  */
 GuiInterface.prototype.GetExtendedEntityState = function(player, ent)
 {
-	var ret = {};
+	var ret = {
+		"armour": null,
+		"attack": null,
+		"barterMarket": null,
+		"buildingAI": null,
+		"healer": null,
+		"obstruction": null,
+		"promotion": null,
+		"resourceCarrying": null,
+		"resourceDropsite": null,
+		"resourceGatherRates": null,
+		"resourceSupply": null,
+	};
 
 	var cmpIdentity = Engine.QueryInterface(ent, IID_Identity);
 
@@ -309,6 +355,9 @@ GuiInterface.prototype.GetExtendedEntityState = function(player, ent)
 		ret.attack.type = type;
 		ret.attack.minRange = range.min;
 		ret.attack.maxRange = range.max;
+		var timers = cmpAttack.GetTimers(type);
+		ret.attack.prepareTime = timers.prepare;
+		ret.attack.repeatTime = timers.repeat;
 		if (type == "Ranged")
 		{
 			ret.attack.elevationBonus = range.elevationBonus;
@@ -346,6 +395,17 @@ GuiInterface.prototype.GetExtendedEntityState = function(player, ent)
 		ret.armour = cmpArmour.GetArmourStrengths();
 	}
 
+	var cmpBuildingAI = Engine.QueryInterface(ent, IID_BuildingAI);
+	if (cmpBuildingAI)
+	{
+		ret.buildingAI = {
+			"defaultArrowCount": cmpBuildingAI.GetDefaultArrowCount(),
+			"garrisonArrowMultiplier": cmpBuildingAI.GetGarrisonArrowMultiplier(),
+			"garrisonArrowClasses": cmpBuildingAI.GetGarrisonArrowClasses(),
+			"arrowCount": cmpBuildingAI.GetArrowCount()
+		};
+	}
+
 	var cmpObstruction = Engine.QueryInterface(ent, IID_Obstruction);
 	if (cmpObstruction)
 	{
@@ -375,7 +435,7 @@ GuiInterface.prototype.GetExtendedEntityState = function(player, ent)
 		ret.resourceGatherRates = cmpResourceGatherer.GetGatherRates();
 		ret.resourceCarrying = cmpResourceGatherer.GetCarryingStatus();
 	}
-
+	
 	var cmpResourceDropsite = Engine.QueryInterface(ent, IID_ResourceDropsite);
 	if (cmpResourceDropsite)
 	{
@@ -444,8 +504,8 @@ GuiInterface.prototype.GetTemplateData = function(player, extendedName)
 	{
 		ret.armour = {
 			"hack": ApplyValueModificationsToTemplate("Armour/Hack", +template.Armour.Hack, player, template),
-			"pierce": ApplyValueModificationsToTemplate("Armour/Pierce", +template.Armour.Hack, player, template),
-			"crush": ApplyValueModificationsToTemplate("Armour/Crush", +template.Armour.Hack, player, template),
+			"pierce": ApplyValueModificationsToTemplate("Armour/Pierce", +template.Armour.Pierce, player, template),
+			"crush": ApplyValueModificationsToTemplate("Armour/Crush", +template.Armour.Crush, player, template),
 		};
 	}
 	
@@ -568,6 +628,7 @@ GuiInterface.prototype.GetTemplateData = function(player, extendedName)
 		};
 		ret.icon = template.Identity.Icon;
 		ret.tooltip =  template.Identity.Tooltip;
+		ret.gateConversionTooltip =  template.Identity.GateConversionTooltip;
 		ret.requiredTechnology = template.Identity.RequiredTechnology;
 		ret.identityClassesString = GetTemplateIdentityClassesString(template);
 	}
@@ -634,7 +695,10 @@ GuiInterface.prototype.GetTechnologyData = function(player, name)
 		"specific": specific,
 		"generic": template.genericName,
 	};
-	ret.icon = "technologies/" + template.icon;
+	if (template.icon)
+		ret.icon = "technologies/" + template.icon;
+	else
+		ret.icon = null;
 	ret.cost = {
 		"food": template.cost ? (+template.cost.food) : 0,
 		"wood": template.cost ? (+template.cost.wood) : 0,
@@ -649,6 +713,9 @@ GuiInterface.prototype.GetTechnologyData = function(player, name)
 	else
 		ret.requirementsTooltip = "";
 	
+	if (template.requirements.class)
+		ret.classRequirements = {"class": template.requirements.class, "number": template.requirements.number};
+	
 	ret.description = template.description;
 	
 	return ret;
@@ -694,7 +761,7 @@ GuiInterface.prototype.GetStartedResearch = function(player)
 			ret[tech].progress = 0;
 	}
 	return ret;
-}
+};
 
 // Returns the battle state of the player.
 GuiInterface.prototype.GetBattleState = function(player)
@@ -717,6 +784,42 @@ GuiInterface.prototype.GetNeededResources = function(player, amounts)
 	return cmpPlayer.GetNeededResources(amounts);
 };
 
+GuiInterface.prototype.AddTimeNotification = function(notification)
+{
+	var time = Engine.QueryInterface(SYSTEM_ENTITY, IID_Timer).GetTime();
+	notification.endTime = notification.duration + time;
+	notification.id = ++this.timeNotificationID;
+	this.timeNotifications.push(notification);
+	this.timeNotifications.sort(function (n1, n2){return n2.endTime - n1.endTime});
+	return this.timeNotificationID;
+};
+
+GuiInterface.prototype.DeleteTimeNotification = function(notificationID)
+{
+	for (var i in this.timeNotifications)
+	{
+		if (this.timeNotifications[i].id == notificationID)
+		{
+			this.timeNotifications.splice(i);
+			return;
+		}
+	}
+};
+
+GuiInterface.prototype.GetTimeNotifications = function(playerID)
+{
+	var time = Engine.QueryInterface(SYSTEM_ENTITY, IID_Timer).GetTime();
+	var toDelete = [];
+	for (var n of this.timeNotifications)
+	{
+		n.time = n.endTime - time;
+		if (n.time < 0)
+			toDelete.push(n.id);
+	}
+	for (var id of toDelete)
+		this.DeleteTimeNotification(id);
+	return this.timeNotifications;
+};
 
 GuiInterface.prototype.PushNotification = function(notification)
 {
@@ -728,7 +831,7 @@ GuiInterface.prototype.GetNextNotification = function()
 	if (this.notifications.length)
 		return this.notifications.pop();
 	else
-		return "";
+		return false;
 };
 
 GuiInterface.prototype.GetAvailableFormations = function(player, data)
@@ -740,12 +843,24 @@ GuiInterface.prototype.GetAvailableFormations = function(player, data)
 
 GuiInterface.prototype.GetFormationRequirements = function(player, data)
 {
-	return GetFormationRequirements(data.formationName);
+	return GetFormationRequirements(data.formationTemplate);
 };
 
 GuiInterface.prototype.CanMoveEntsIntoFormation = function(player, data)
 {
-	return CanMoveEntsIntoFormation(data.ents, data.formationName);
+	return CanMoveEntsIntoFormation(data.ents, data.formationTemplate);
+};
+
+GuiInterface.prototype.GetFormationInfoFromTemplate = function(player, data)
+{
+	var r = {};
+	var cmpTemplateManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_TemplateManager);
+	var template = cmpTemplateManager.GetTemplate(data.templateName);
+	if (!template || !template.Formation)
+		return r;
+	r.name = template.Formation.FormationName;
+	r.tooltip = template.Formation.DisabledTooltip || "";
+	return r;
 };
 
 GuiInterface.prototype.IsFormationSelected = function(player, data)
@@ -757,7 +872,7 @@ GuiInterface.prototype.IsFormationSelected = function(player, data)
 		{
 			// GetLastFormationName is named in a strange way as it (also) is
 			// the value of the current formation (see Formation.js LoadFormation)
-			if (cmpUnitAI.GetLastFormationName() == data.formationName)
+			if (cmpUnitAI.GetLastFormationTemplate() == data.formationTemplate)
 				return true;
 		}
 	}
@@ -879,10 +994,11 @@ GuiInterface.prototype.DisplayRallyPoint = function(player, cmd)
 		if (pos)
 		{
 			// Only update the position if we changed it (cmd.queued is set)
-			if (cmd.queued == true)
-				cmpRallyPointRenderer.AddPosition({'x': pos.x, 'y': pos.z}); // AddPosition takes a CFixedVector2D which has X/Y components, not X/Z
-			else if (cmd.queued == false)
-				cmpRallyPointRenderer.SetPosition({'x': pos.x, 'y': pos.z}); // SetPosition takes a CFixedVector2D which has X/Y components, not X/Z
+			if ("queued" in cmd)
+				if (cmd.queued == true)
+					cmpRallyPointRenderer.AddPosition({'x': pos.x, 'y': pos.z}); // AddPosition takes a CFixedVector2D which has X/Y components, not X/Z
+				else
+					cmpRallyPointRenderer.SetPosition({'x': pos.x, 'y': pos.z}); // SetPosition takes a CFixedVector2D which has X/Y components, not X/Z
 			// rebuild the renderer when not set (when reading saved game or in case of building update)
 			else if (!cmpRallyPointRenderer.IsSet())
 				for each (var posi in cmpRallyPoint.GetPositions())
@@ -903,8 +1019,11 @@ GuiInterface.prototype.DisplayRallyPoint = function(player, cmd)
  * 
  * Returns result object from CheckPlacement:
  * 	{
- *		"success":	true iff the placement is valid, else false
- *		"message":	message to display in UI for invalid placement, else empty string
+ *		"success":             true iff the placement is valid, else false
+ *		"message":             message to display in UI for invalid placement, else ""
+ *		"parameters":          parameters to use in the message
+ *		"translateMessage":    localisation info
+ *		"translateParameters": localisation info
  *  }
  */
 GuiInterface.prototype.SetBuildingPlacementPreview = function(player, cmd)
@@ -912,6 +1031,9 @@ GuiInterface.prototype.SetBuildingPlacementPreview = function(player, cmd)
 	var result = {
 		"success": false,
 		"message": "",
+		"parameters": {},
+		"translateMessage": false,
+		"translateParameters": [],
 	}
 
 	// See if we're changing template
@@ -1647,47 +1769,36 @@ GuiInterface.prototype.PlaySound = function(player, data)
 	PlaySound(data.name, data.entity);
 };
 
-function isIdleUnit(ent, idleClass)
-{
-	var cmpUnitAI = Engine.QueryInterface(ent, IID_UnitAI);
-	var cmpIdentity = Engine.QueryInterface(ent, IID_Identity);
-	
-	// TODO: Do something with garrisoned idle units
-	return (cmpUnitAI && cmpIdentity && cmpUnitAI.IsIdle() && !cmpUnitAI.IsGarrisoned() && idleClass && cmpIdentity.HasClass(idleClass));
-}
-
 GuiInterface.prototype.FindIdleUnits = function(player, data)
 {
-	var rangeMan = Engine.QueryInterface(SYSTEM_ENTITY, IID_RangeManager);
-	var playerEntities = rangeMan.GetEntitiesByPlayer(player).filter( function(e) {
+	var cmpRangeManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_RangeManager);
+	var playerEntities = cmpRangeManager.GetEntitiesByPlayer(player).filter( function(e) {
 		var cmpUnitAI = Engine.QueryInterface(e, IID_UnitAI);
-		if (cmpUnitAI)
-			return true;
-		return false;
+		if (!cmpUnitAI || !cmpUnitAI.IsIdle() || cmpUnitAI.IsGarrisoned())
+			return false;
+		var cmpIdentity = Engine.QueryInterface(e, IID_Identity);
+		if (!cmpIdentity || !cmpIdentity.HasClass(data.idleClass))
+			return false;
+		return true;
 	});
 
 	var idleUnits = [];
-	var noFilter = (data.prevUnit == undefined && data.excludeUnits == undefined);
 
 	for (var j = 0; j < playerEntities.length; ++j)
 	{
 		var ent = playerEntities[j];
-		if (!isIdleUnit(ent, data.idleClass))
-			continue;
 
-		if (noFilter || ((data.prevUnit == undefined || ent > data.prevUnit) &&
-				(data.excludeUnits == undefined || data.excludeUnits.indexOf(ent) == -1)))
-		{
-			idleUnits.push(ent);
-			playerEntities.splice(j--, 1);
-		}
+		if (ent <= data.prevUnit|0 || data.excludeUnits.indexOf(ent) > -1)
+			continue;
+		idleUnits.push(ent);
+		playerEntities.splice(j--, 1);
 
 		if (data.limit && idleUnits.length >= data.limit)
 			break;
 	}
 
 	return idleUnits;
-}
+};
 
 GuiInterface.prototype.GetTradingRouteGain = function(player, data)
 {
@@ -1695,7 +1806,7 @@ GuiInterface.prototype.GetTradingRouteGain = function(player, data)
 		return null;
 
 	return CalculateTraderGain(data.firstMarket, data.secondMarket, data.template);
-}
+};
 
 GuiInterface.prototype.GetTradingDetails = function(player, data)
 {
@@ -1709,7 +1820,6 @@ GuiInterface.prototype.GetTradingDetails = function(player, data)
 	{
 		result = {
 			"type": "is first",
-			"goods": cmpEntityTrader.GetPreferredGoods(),
 			"hasBothMarkets": cmpEntityTrader.HasBothMarkets()
 		};
 		if (cmpEntityTrader.HasBothMarkets())
@@ -1720,7 +1830,6 @@ GuiInterface.prototype.GetTradingDetails = function(player, data)
 		result = {
 			"type": "is second",
 			"gain": cmpEntityTrader.GetGain(),
-			"goods": cmpEntityTrader.GetPreferredGoods()
 		};
 	}
 	else if (!firstMarket)
@@ -1732,7 +1841,6 @@ GuiInterface.prototype.GetTradingDetails = function(player, data)
 		result = {
 			"type": "set second",
 			"gain": cmpEntityTrader.CalculateGain(firstMarket, data.target),
-			"goods": cmpEntityTrader.GetPreferredGoods()
 		};
 	}
 	else
@@ -1767,7 +1875,7 @@ GuiInterface.prototype.GetBatchTime = function(player, data)
 GuiInterface.prototype.IsMapRevealed = function(player)
 {
 	var cmpRangeManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_RangeManager);
-	return cmpRangeManager.GetLosRevealAll(-1);
+	return cmpRangeManager.GetLosRevealAll(player);
 };
 
 GuiInterface.prototype.SetPathfinderDebugOverlay = function(player, enabled)
@@ -1798,10 +1906,55 @@ GuiInterface.prototype.SetRangeDebugOverlay = function(player, enabled)
 	cmpRangeManager.SetDebugOverlay(enabled);
 };
 
+GuiInterface.prototype.GetTraderNumber = function(player)
+{
+	var cmpRangeManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_RangeManager);
+	var traders = cmpRangeManager.GetEntitiesByPlayer(player).filter( function(e) {
+		return Engine.QueryInterface(e, IID_Trader);
+	});
+
+	var landTrader = { "total": 0, "trading": 0, "garrisoned": 0 };
+	var shipTrader = { "total": 0, "trading": 0 };
+	for each (var ent in traders)
+	{
+		var cmpIdentity =  Engine.QueryInterface(ent, IID_Identity);
+		var cmpUnitAI =  Engine.QueryInterface(ent, IID_UnitAI);
+		if (!cmpIdentity || !cmpUnitAI)
+			continue;
+		if (cmpIdentity.HasClass("Ship"))
+		{
+			++shipTrader.total;
+			if (cmpUnitAI.order && cmpUnitAI.order.type == "Trade")
+				++shipTrader.trading;
+		}
+		else
+		{
+			++landTrader.total;
+			if (cmpUnitAI.order && cmpUnitAI.order.type == "Trade")
+				++landTrader.trading;
+			if (cmpUnitAI.order && cmpUnitAI.order.type == "Garrison")
+			{
+				var holder = cmpUnitAI.order.data.target;
+				var cmpHolderUnitAI = Engine.QueryInterface(holder, IID_UnitAI);
+				if (cmpHolderUnitAI && cmpHolderUnitAI.order && cmpHolderUnitAI.order.type == "Trade")
+					++landTrader.garrisoned;
+			}
+		}
+	}
+
+	return { "landTrader": landTrader, "shipTrader": shipTrader };
+};
+
+GuiInterface.prototype.GetTradingGoods = function(player, tradingGoods)
+{
+	var cmpPlayer = QueryPlayerIDInterface(player, IID_Player);
+	return cmpPlayer.GetTradingGoods();
+};
+
 GuiInterface.prototype.OnGlobalEntityRenamed = function(msg)
 {
 	this.renamedEntities.push(msg);
-}
+};
 
 // List the GuiInterface functions that can be safely called by GUI scripts.
 // (GUI scripts are non-deterministic and untrusted, so these functions must be
@@ -1826,11 +1979,13 @@ var exposedFunctions = {
 	"GetIncomingAttacks": 1,
 	"GetNeededResources": 1,
 	"GetNextNotification": 1,
+	"GetTimeNotifications": 1,
 
 	"GetAvailableFormations": 1,
 	"GetFormationRequirements": 1,
 	"CanMoveEntsIntoFormation": 1,
 	"IsFormationSelected": 1,
+	"GetFormationInfoFromTemplate": 1,
 	"IsStanceSelected": 1,
 
 	"SetSelectionHighlight": 1,
@@ -1852,6 +2007,9 @@ var exposedFunctions = {
 	"SetObstructionDebugOverlay": 1,
 	"SetMotionDebugOverlay": 1,
 	"SetRangeDebugOverlay": 1,
+
+	"GetTraderNumber": 1,
+	"GetTradingGoods": 1,
 };
 
 GuiInterface.prototype.ScriptCall = function(player, name, args)
