@@ -29,6 +29,11 @@ Identity.prototype.Schema =
 			"<text/>" +
 		"</element>" +
 	"</optional>" +
+	"<optional>" +
+		"<element name='GateConversionTooltip'>" +
+			"<text/>" +
+		"</element>" +
+	"</optional>" +
 	"<optional>" +
 		"<element name='Rollover'>" +
 			"<text/>" +
@@ -95,14 +100,10 @@ Identity.prototype.GetRank = function()
 Identity.prototype.GetClassesList = function()
 {
 	if (this.template.Classes && "_string" in this.template.Classes)
-	{
-		var string = this.template.Classes._string;
-		return string.split(/\s+/);
-	}
-	else
-	{
-		return [];
-	}
+		return ( this.template.Classes._string + " " + this.GetRank() ).split(/\s+/);
+	if (this.GetRank().length)
+		return [this.GetRank()];
+	return [];
 };
 
 Identity.prototype.HasClass = function(name)
@@ -123,9 +124,9 @@ Identity.prototype.GetFormationsList = function()
 	}
 };
 
-Identity.prototype.CanUseFormation = function(name)
+Identity.prototype.CanUseFormation = function(template)
 {
-	return this.GetFormationsList().indexOf(name) != -1;
+	return this.GetFormationsList().indexOf(template) != -1;
 };
 
 Identity.prototype.GetSelectionGroupName = function()
