@@ -11,8 +11,20 @@ PlayerManager.prototype.Init = function()
 PlayerManager.prototype.AddPlayer = function(ent)
 {
 	var id = this.playerEntities.length;
-	Engine.QueryInterface(ent, IID_Player).SetPlayerID(id);
+	var cmpPlayer = Engine.QueryInterface(ent, IID_Player)
+	cmpPlayer.SetPlayerID(id);
 	this.playerEntities.push(ent);
+	// initialize / update the diplomacy arrays
+	var newDiplo = [];
+	for (var i = 0; i < id; i++)
+	{
+		var cmpOtherPlayer = Engine.QueryInterface(this.GetPlayerByID(i), IID_Player);
+		cmpOtherPlayer.diplomacy[id] = -1;
+		newDiplo[i] = -1;
+	}
+	newDiplo[id] = 1;
+	cmpPlayer.SetDiplomacy(newDiplo);
+	
 	return id;
 };
 
@@ -25,6 +37,10 @@ PlayerManager.prototype.GetPlayerByID = function(id)
 	if (id in this.playerEntities)
 		return this.playerEntities[id];
 
+	// All players at or below ID 0 get gaia-level data. (Observers for example)
+	if (id <= 0)
+		return this.playerEntities[0];
+
 	var stack = new Error().stack.trimRight().replace(/^/mg, '  '); // indent each line
 	warn("GetPlayerByID: no player defined for id '"+id+"'\n"+stack);
 
