@@ -49,8 +49,6 @@ TechnologyManager.prototype.Init = function ()
 		if (this.allTechs[key].autoResearch || this.allTechs[key].top)
 			this.autoResearchTech[key] = this.allTechs[key];
 	}
-	
-	this.UpdateAutoResearch();
 };
 
 TechnologyManager.prototype.OnUpdate = function () 
@@ -76,6 +74,9 @@ TechnologyManager.prototype.UpdateAutoResearch = function ()
 
 TechnologyManager.prototype.GetTechnologyTemplate = function (tech)
 {
+	if (!(tech in this.allTechs))
+		return undefined;
+
 	return this.allTechs[tech];
 };
 
@@ -120,7 +121,7 @@ TechnologyManager.prototype.CanResearch = function (tech)
 	if (this.IsInProgress(tech))
 		return false;
 	
-	return this.CheckTechnologyRequirements(template.requirements);
+	return this.CheckTechnologyRequirements(template.requirements || null);
 };
 
 // Private function for checking a set of requirements is met
@@ -226,13 +227,17 @@ TechnologyManager.prototype.OnGlobalOwnershipChanged = function (msg)
 				var modifications = this.modifications[name];
 				var component = name.split("/")[0];
 				for (var i in modifications)
-					if (!modifiedComponents[component] && DoesModificationApply(modifications[i], classes))
-						modifiedComponents[component] = true;
+ 					if (DoesModificationApply(modifications[i], classes))
+					{
+						if (!modifiedComponents[component])
+							modifiedComponents[component] = [];
+						modifiedComponents[component].push(name);
+					}
 			}
 
 			// Send mesage(s) to the entity so it knows about researched techs
 			for (var component in modifiedComponents)
-				Engine.PostMessage(msg.entity, MT_ValueModification, { "component": component });
+				Engine.PostMessage(msg.entity, MT_ValueModification, { "entities": [msg.entity], "component": component, "valueNames": modifiedComponents[component] });
 		}
 	}
 	if (msg.from == playerID)
@@ -307,14 +312,15 @@ TechnologyManager.prototype.ResearchTechnology = function (tech)
 			if (!this.modifications[modification.value])
 				this.modifications[modification.value] = [];
 			
-			var modAffects = [];
+			var modAffects = affects.slice();
 			if (modification.affects)
 			{
-				for (var j in modification.affects)
-					modAffects.push(modification.affects[j].split(/\s+/));
+				var extraAffects = modification.affects.split(/\s+/);
+				for (var a in modAffects)
+					modAffects[a] = modAffects[a].concat(extraAffects);
 			}
 			
-			var mod = {"affects": affects.concat(modAffects)};
+			var mod = {"affects": modAffects};
 			
 			// copy the modification data into our new data structure
 			for (var j in modification)
@@ -322,16 +328,28 @@ TechnologyManager.prototype.ResearchTechnology = function (tech)
 					mod[j] = modification[j];
 			
 			this.modifications[modification.value].push(mod);
-			modifiedComponents[modification.value.split("/")[0]] = true;
+			var component = modification.value.split("/")[0];
+			if (!modifiedComponents[component])
+				modifiedComponents[component] = [];
+			modifiedComponents[component].push(modification.value);
 			this.modificationCache[modification.value] = {};
 		}
 	}
 	
 	this.UpdateAutoResearch();
 	
-	// TODO: Handle technology broadcasting for autoresearch properly (some components might not be initialized currently)
+	var cmpPlayer = Engine.QueryInterface(this.entity, IID_Player);
+	if (!cmpPlayer || cmpPlayer.GetPlayerID() === undefined)
+		return;
+	var playerID = cmpPlayer.GetPlayerID();
+	var cmpRangeManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_RangeManager);
+	var ents = cmpRangeManager.GetEntitiesByPlayer(playerID);
+
 	for (var component in modifiedComponents)
-		Engine.BroadcastMessage(MT_ValueModification, { "component": component });
+	{
+		Engine.PostMessage(SYSTEM_ENTITY, MT_TemplateModification, { "player": playerID, "component": component, "valueNames": modifiedComponents[component]});
+		Engine.BroadcastMessage(MT_ValueModification, { "entities": ents, "component": component, "valueNames": modifiedComponents[component]});
+	}
 };
 
 // Clears the cached data for an entity from the modifications cache
@@ -356,9 +374,9 @@ TechnologyManager.prototype.ApplyModifications = function(valueName, curValue, e
 		this.modificationCache[valueName][ent] = {"origValue": curValue};
 		var cmpTemplateManager = Engine.QueryInterface(SYSTEM_ENTITY, IID_TemplateManager);
 		var templateName = cmpTemplateManager.GetCurrentTemplateName(ent);
-		// Ensure that preview entites have the same properties as the final building
-		if (templateName.indexOf("preview|") != -1)
-			templateName = templateName.slice(8);
+		// Ensure that preview or construction entites have the same properties as the final building
+		if (templateName.indexOf("preview|") > -1 || templateName.indexOf("construction|") > -1 )
+			templateName = templateName.slice(templateName.indexOf("|") + 1);
 		this.modificationCache[valueName][ent].newValue = GetTechModifiedProperty(this.modifications, cmpTemplateManager.GetTemplate(templateName), valueName, curValue);
 	}
 	
