@@ -1,17 +1,14 @@
 function TrainingRestrictions() {}
 
 TrainingRestrictions.prototype.Schema =
-	"<a:help>Specifies unit training restrictions, currently only unit category.</a:help>" +
+	"<a:help>Specifies unit training restrictions, currently only unit category</a:help>" +
 	"<a:example>" +
 		"<TrainingRestrictions>" +
 			"<Category>Hero</Category>" +
 		"</TrainingRestrictions>" +
 	"</a:example>" +
-	"<element name='Category' a:help='Specifies the category of this unit, for satisfying special constraints.'>" +
-		"<choice>" +
-			"<value>Hero</value>" +
-			"<value>FemaleCitizen</value>" +
-		"</choice>" +
+	"<element name='Category' a:help='Specifies the category of this unit, for satisfying special constraints. Choices include: Hero, FemaleCitizen, WarDog'>" +
+		"<text/>" +
 	"</element>";
 
 TrainingRestrictions.prototype.GetCategory = function()
