@@ -5,9 +5,11 @@ var g_ServerName = "";
 var g_IsRejoining = false;
 var g_GameAttributes; // used when rejoining
 var g_PlayerAssignments; // used when rejoining
+var g_userRating; // player rating
 
 function init(attribs)
 {
+	g_userRating = attribs.rating;
 	switch (attribs.multiplayerGameType)
 	{
 	case "join":
@@ -18,24 +20,24 @@ function init(attribs)
 		}
 		else
 		{
-			getGUIObjectByName("pageJoin").hidden = false;
-			getGUIObjectByName("pageHost").hidden = true;
+			Engine.GetGUIObjectByName("pageJoin").hidden = false;
+			Engine.GetGUIObjectByName("pageHost").hidden = true;
 		}
 		break;
 	case "host":
-		getGUIObjectByName("pageJoin").hidden = true;
-		getGUIObjectByName("pageHost").hidden = false;
+		Engine.GetGUIObjectByName("pageJoin").hidden = true;
+		Engine.GetGUIObjectByName("pageHost").hidden = false;
 		if(Engine.HasXmppClient())
 		{
-			getGUIObjectByName("hostServerNameWrapper").hidden = false;
-			getGUIObjectByName("hostPlayerName").caption = attribs.name;
-			getGUIObjectByName("hostServerName").caption = attribs.name + "'s game";
+			Engine.GetGUIObjectByName("hostServerNameWrapper").hidden = false;
+			Engine.GetGUIObjectByName("hostPlayerName").caption = attribs.name;
+			Engine.GetGUIObjectByName("hostServerName").caption = sprintf(translate("%(name)s's game"), { name: attribs.name });
 		}
 		else
-			getGUIObjectByName("hostPlayerNameWrapper").hidden = false;
+			Engine.GetGUIObjectByName("hostPlayerNameWrapper").hidden = false;
 		break;
 	default:
-		error("Unrecognised multiplayer game type : " + attribs.multiplayerGameType);
+		error(sprintf("Unrecognised multiplayer game type: %(gameType)s", { gameType: multiplayerGameType }));
 		break;
 	}
 }
@@ -55,7 +57,7 @@ function startConnectionStatus(type)
 	g_GameType = type;
 	g_IsConnecting = true;
 	g_IsRejoining = false;
-	getGUIObjectByName("connectionStatus").caption = "Connecting to server...";
+	Engine.GetGUIObjectByName("connectionStatus").caption = translate("Connecting to server...");
 }
 
 function onTick()
@@ -74,7 +76,7 @@ function pollAndHandleNetworkClient()
 		if (!message)
 			break;
 
-		log("Net message: "+uneval(message));
+		log(sprintf(translate("Net message: %(message)s"), { message: uneval(message) }));
 
 		// If we're rejoining an active game, we don't want to actually display
 		// the game setup screen, so perform similar processing to gamesetup.js
@@ -92,7 +94,7 @@ function pollAndHandleNetworkClient()
 					return;
 
 				default:
-					error("Unrecognised netstatus type "+message.status);
+					error(sprintf("Unrecognised netstatus type %(netType)s", { netType: message.status }));
 					break;
 				}
 				break;
@@ -118,7 +120,7 @@ function pollAndHandleNetworkClient()
 				break;
 
 			default:
-				error("Unrecognised net message type "+message.type);
+				error(sprintf("Unrecognised net message type %(messageType)s", { messageType: message.type }));
 			}
 		}
 		else
@@ -131,13 +133,13 @@ function pollAndHandleNetworkClient()
 				switch (message.status)
 				{
 				case "connected":
-					getGUIObjectByName("connectionStatus").caption = "Registering with server...";
+					Engine.GetGUIObjectByName("connectionStatus").caption = translate("Registering with server...");
 					break;
 
 				case "authenticated":
 					if (message.rejoining)
 					{
-						getGUIObjectByName("connectionStatus").caption = "Game has already started - rejoining...";
+						Engine.GetGUIObjectByName("connectionStatus").caption = translate("Game has already started, rejoining...");
 						g_IsRejoining = true;
 						return; // we'll process the game setup messages in the next tick
 					}
@@ -153,12 +155,12 @@ function pollAndHandleNetworkClient()
 					return;
 
 				default:
-					error("Unrecognised netstatus type "+message.status);
+					error(sprintf("Unrecognised netstatus type %(netType)s", { netType: message.status }));
 					break;
 				}
 				break;
 			default:
-				error("Unrecognised net message type "+message.type);
+				error(sprintf("Unrecognised net message type %(messageType)s", { messageType: message.type }));
 				break;
 			}
 		}
@@ -167,8 +169,8 @@ function pollAndHandleNetworkClient()
 
 function switchSetupPage(oldpage, newpage)
 {
-	getGUIObjectByName(oldpage).hidden = true;
-	getGUIObjectByName(newpage).hidden = false;
+	Engine.GetGUIObjectByName(oldpage).hidden = true;
+	Engine.GetGUIObjectByName(newpage).hidden = false;
 }
 
 function startHost(playername, servername)
@@ -176,24 +178,27 @@ function startHost(playername, servername)
 	// Disallow identically named games in the multiplayer lobby
 	if (Engine.HasXmppClient())
 	{
-		for each (g in Engine.GetGameList())
+		for each (var g in Engine.GetGameList())
 		{
 			if (g.name === servername)
 			{
-				getGUIObjectByName("hostFeedback").caption = "Game name already in use.";
+				Engine.GetGUIObjectByName("hostFeedback").caption = translate("Game name already in use.");
 				return false;
 			}
 		}
 	}
 	try
 	{
-		Engine.StartNetworkHost(playername);
+		if (g_userRating)
+			Engine.StartNetworkHost(playername + " (" + g_userRating + ")");
+		else
+			Engine.StartNetworkHost(playername);
 	}
 	catch (e)
 	{
 		cancelSetup();
 		messageBox(400, 200,
-			"Cannot host game: " + e.message + ".",
+			sprintf("Cannot host game: %(message)s.", { message: e.message }),
 			"Error", 2);
 		return false;
 	}
@@ -210,13 +215,16 @@ function startJoin(playername, ip)
 {
 	try
 	{
-		Engine.StartNetworkJoin(playername, ip);
+		if (g_userRating)
+			Engine.StartNetworkJoin(playername + " (" + g_userRating + ")", ip);
+		else
+			Engine.StartNetworkJoin(playername, ip);
 	}
 	catch (e)
 	{
 		cancelSetup();
 		messageBox(400, 200,
-			"Cannot join game: " + e.message + ".",
+			sprintf("Cannot join game: %(message)s.", { message: e.message }),
 			"Error", 2);
 		return false;
 	}
@@ -227,3 +235,8 @@ function startJoin(playername, ip)
 		Engine.LobbySetPlayerPresence("playing");
 	return true;
 }
+
+function getDefaultGameName()
+{
+	return sprintf(translate("%(playername)s's game"), { playername: Engine.ConfigDB_GetValue("user", "playername")});
+}
