@@ -54,6 +54,11 @@ function LoadPlayerSettings(settings, newPlayers)
 
 			// Add player to player manager
 			cmpPlayerManager.AddPlayer(entID);
+
+			// Properly autoresearch techs on init.
+			var cmpTechManager = Engine.QueryInterface(entID, IID_TechnologyManager);
+			if (cmpTechManager !== undefined)
+				cmpTechManager.UpdateAutoResearch();
 		}
 	}
 
@@ -92,7 +97,6 @@ function LoadPlayerSettings(settings, newPlayers)
 			else
 			{
 				// Init diplomacy
-				cmpPlayer.SetDiplomacy(new Array(numPlayers));
 				var myTeam = getSetting(pData, pDefs, "Team");
 
 				// Set all but self as enemies as SetTeam takes care of allies
