@@ -11,7 +11,7 @@ function init(initData, hotloadData)
 	// Play main menu music
 	global.music.setState(global.music.states.MENU);
 
-	userReportEnabledText = getGUIObjectByName("userReportEnabledText").caption;
+	userReportEnabledText = Engine.GetGUIObjectByName("userReportEnabledText").caption;
 
 	// initialize currentSubmenuType with placeholder to avoid null when switching
 	currentSubmenuType = "submenuSinglePlayer";
@@ -32,9 +32,9 @@ function scrollBackgrounds(background)
 {
 	if (background == "hellenes1")
 	{
-		var layer1 = getGUIObjectByName("backgroundHele1-1");
-		var layer2 = getGUIObjectByName("backgroundHele1-2");
-		var layer3 = getGUIObjectByName("backgroundHele1-3");
+		var layer1 = Engine.GetGUIObjectByName("backgroundHele1-1");
+		var layer2 = Engine.GetGUIObjectByName("backgroundHele1-2");
+		var layer3 = Engine.GetGUIObjectByName("backgroundHele1-3");
 		
 		layer1.hidden = false;
 		layer2.hidden = false;
@@ -59,10 +59,10 @@ function scrollBackgrounds(background)
 	
 	if (background == "persians1")
 	{
-		var layer1 = getGUIObjectByName("backgroundPers1-1");
-		var layer2 = getGUIObjectByName("backgroundPers1-2");
-		var layer3 = getGUIObjectByName("backgroundPers1-3");
-		var layer4 = getGUIObjectByName("backgroundPers1-4");
+		var layer1 = Engine.GetGUIObjectByName("backgroundPers1-1");
+		var layer2 = Engine.GetGUIObjectByName("backgroundPers1-2");
+		var layer3 = Engine.GetGUIObjectByName("backgroundPers1-3");
+		var layer4 = Engine.GetGUIObjectByName("backgroundPers1-4");
 		
 		layer1.hidden = false;
 		layer2.hidden = false;
@@ -91,7 +91,7 @@ function scrollBackgrounds(background)
 
 function submitUserReportMessage()
 {
-	var input = getGUIObjectByName("userReportMessageInput");
+	var input = Engine.GetGUIObjectByName("userReportMessageInput");
 	var msg = input.caption;
 	if (msg.length)
 		Engine.SubmitUserReport("message", 1, msg);
@@ -103,34 +103,34 @@ function formatUserReportStatus(status)
 	var d = status.split(/:/, 3);
 
 	if (d[0] == "disabled")
-		return "disabled";
+		return translate("disabled");
 
 	if (d[0] == "connecting")
-		return "connecting to server";
+		return translate("connecting to server");
 
 	if (d[0] == "sending")
 	{
 		var done = d[1];
-		return "uploading (" + Math.floor(100*done) + "%)";
+		return sprintf(translate("uploading (%f%%)"), Math.floor(100*done));
 	}
 
 	if (d[0] == "completed")
 	{
 		var httpCode = d[1];
 		if (httpCode == 200)
-			return "upload succeeded";
+			return translate("upload succeeded");
 		else
-			return "upload failed (" + httpCode + ")";
+			return sprintf(translate("upload failed (%(errorCode)s)"), { errorCode: httpCode });
 	}
 
 	if (d[0] == "failed")
 	{
 		var errCode = d[1];
 		var errMessage = d[2];
-		return "upload failed (" + errMessage + ")";
+		return sprintf(translate("upload failed (%(errorMessage)s)"), { errorMessage: errMessage });
 	}
 
-	return "unknown";
+	return translate("unknown");
 }
 
 var lastTickTime = new Date;
@@ -148,7 +148,7 @@ function onTick()
 
 	if (Engine.IsUserReportEnabled())
 	{
-		getGUIObjectByName("userReportEnabledText").caption = 
+		Engine.GetGUIObjectByName("userReportEnabledText").caption = 
 			userReportEnabledText.replace(/\$status/,
 				formatUserReportStatus(Engine.GetUserReportStatus()));
 	}
@@ -158,27 +158,45 @@ function onTick()
 	{
 		g_ShowSplashScreens = false;
 
-		if (Engine.IsSplashScreenEnabled())
-			Engine.PushGuiPage("page_splashscreen.xml", { "page": "splashscreen" } );
-
-		// Warn about removing fixed render path
-		if (Engine.Renderer_GetRenderPath() == "fixed")
-			messageBox(
-				600,
-				300,
-				"[font=\"serif-bold-16\"][color=\"200 20 20\"]Warning:[/color] You appear to be using non-shader (fixed function) graphics. This option will be removed in a future 0 A.D. release, to allow for more advanced graphics features. We advise upgrading your graphics card to a more recent, shader-compatible model.\n\nPlease press \"Read More\" for more information or \"Ok\" to continue.",
-				"WARNING!",
-				0,
-				["Ok", "Read More"],
-				[null, function() { Engine.OpenURL("http://www.wildfiregames.com/forum/index.php?showtopic=16734"); }]
-			);
+		if (Engine.ConfigDB_GetValue("user", "splashscreendisable") !== "true" 
+			&& Engine.ConfigDB_GetValue("user", "splashscreenversion") < Engine.GetFileMTime("gui/splashscreen/splashscreen.txt"))
+            Engine.PushGuiPage("page_splashscreen.xml", { "page": "splashscreen", callback : "SplashScreenClosedCallback" } );
+		else
+			ShowRenderPathMessage();
 	}
 }
 
+function ShowRenderPathMessage()
+{
+	// Warn about removing fixed render path
+	if (Engine.Renderer_GetRenderPath() == "fixed")
+		messageBox(
+			600,
+			300,
+			"[font=\"sans-bold-16\"]" +
+			sprintf(translate("%(startWarning)sWarning:%(endWarning)s You appear to be using non-shader (fixed function) graphics. This option will be removed in a future 0 A.D. release, to allow for more advanced graphics features. We advise upgrading your graphics card to a more recent, shader-compatible model."), { startWarning: "[color=\"200 20 20\"]", endWarning: "[/color]"}) +
+			"\n\n" +
+			// Translation: This is the second paragraph of a warning. The
+			// warning explains that the user is using “non-shader“ graphics,
+			// and that in the future this will not be supported by the game, so
+			// the user will need a better graphics card.
+			translate("Please press \"Read More\" for more information or \"OK\" to continue."),
+			translate("WARNING!"),
+			0,
+			[translate("OK"), translate("Read More")],
+			[ null, function() { Engine.OpenURL("http://www.wildfiregames.com/forum/index.php?showtopic=16734"); } ]
+		);
+}
+
+function SplashScreenClosedCallback()
+{
+	ShowRenderPathMessage();
+}
+
 function EnableUserReport(Enabled)
 {
-	getGUIObjectByName("userReportDisabled").hidden = Enabled;
- 	getGUIObjectByName("userReportEnabled").hidden = !Enabled;
+	Engine.GetGUIObjectByName("userReportDisabled").hidden = Enabled;
+ 	Engine.GetGUIObjectByName("userReportEnabled").hidden = !Enabled;
  	Engine.SetUserReportEnabled(Enabled);
 }
 
@@ -187,25 +205,17 @@ function EnableUserReport(Enabled)
  * MENU FUNCTIONS
  */
 
-// Temporarily adding this here
-//const BUTTON_SOUND = "audio/interface/ui/ui_button_longclick.ogg";
-//function playButtonSound()
-//{
-//    var buttonSound = new Sound(BUTTON_SOUND);
-//    buttonSound.play();
-//}
-
 // Slide menu
 function updateMenuPosition(dt)
 {
-	var submenu = getGUIObjectByName("submenu");
+	var submenu = Engine.GetGUIObjectByName("submenu");
 
 	if (submenu.hidden == false)
 	{
 		// Number of pixels per millisecond to move
 		const SPEED = 1.2;
 
-		var maxOffset = getGUIObjectByName("mainMenu").size.right - submenu.size.left;
+		var maxOffset = Engine.GetGUIObjectByName("mainMenu").size.right - submenu.size.left;
 		if (maxOffset > 0)
 		{
 			var offset = Math.min(SPEED * dt, maxOffset);
@@ -222,10 +232,10 @@ function openMenu(newSubmenu, position, buttonHeight, numButtons)
 {
 	// switch to new submenu type
 	currentSubmenuType = newSubmenu;
-	getGUIObjectByName(currentSubmenuType).hidden = false;
+	Engine.GetGUIObjectByName(currentSubmenuType).hidden = false;
 
 	// set position of new submenu
-	var submenu = getGUIObjectByName("submenu");
+	var submenu = Engine.GetGUIObjectByName("submenu");
 	var top = position - MARGIN;
 	var bottom = position + ((buttonHeight + MARGIN) * numButtons);
 	submenu.size = submenu.size.left + " " + top + " " + submenu.size.right + " " + bottom;
@@ -234,7 +244,7 @@ function openMenu(newSubmenu, position, buttonHeight, numButtons)
 	blendSubmenuIntoMain(top, bottom);
 
 	// Reveal submenu
-	getGUIObjectByName("submenu").hidden = false;
+	Engine.GetGUIObjectByName("submenu").hidden = false;
 }
 
 // Closes the menu and resets position
@@ -243,64 +253,36 @@ function closeMenu()
 //	playButtonSound();
 
 	// remove old submenu type
-	getGUIObjectByName(currentSubmenuType).hidden = true;
+	Engine.GetGUIObjectByName(currentSubmenuType).hidden = true;
 
 	// hide submenu and reset position
-	var submenu = getGUIObjectByName("submenu");
+	var submenu = Engine.GetGUIObjectByName("submenu");
 	submenu.hidden = true;
-	submenu.size = getGUIObjectByName("mainMenu").size;
+	submenu.size = Engine.GetGUIObjectByName("mainMenu").size;
 
 	// reset main menu panel right border
-	getGUIObjectByName("MainMenuPanelRightBorderTop").size = "100%-2 0 100% 100%";
+	Engine.GetGUIObjectByName("MainMenuPanelRightBorderTop").size = "100%-2 0 100% 100%";
 }
 
 // Sizes right border on main menu panel to match the submenu
 function blendSubmenuIntoMain(topPosition, bottomPosition)
 {
-	var topSprite = getGUIObjectByName("MainMenuPanelRightBorderTop");
+	var topSprite = Engine.GetGUIObjectByName("MainMenuPanelRightBorderTop");
 	topSprite.size = "100%-2 0 100% " + (topPosition + MARGIN);
 
-	var bottomSprite = getGUIObjectByName("MainMenuPanelRightBorderBottom");
+	var bottomSprite = Engine.GetGUIObjectByName("MainMenuPanelRightBorderBottom");
 	bottomSprite.size = "100%-2 " + (bottomPosition) + " 100% 100%";
 }
 
+function getBuildString()
+{
+	return sprintf(translate("Build: %(buildDate)s (%(revision)s)"), { buildDate: Engine.GetBuildTimestamp(0), revision: Engine.GetBuildTimestamp(2) });
+}
+
 /*
  * FUNCTIONS BELOW DO NOT WORK YET
  */
 
-//// Switch to a given options tab window.
-//function openOptionsTab(tabName)
-//{
-//	// Hide the other tabs.
-//	for (var i = 1; i <= 3; i++)
-//	{
-//		switch (i)
-//		{
-//			case 1:
-//				var tmpName = "pgOptionsAudio";
-//			break;
-//			case 2:
-//				var tmpName = "pgOptionsVideo";
-//			break;
-//			case 3:
-//				var tmpName = "pgOptionsGame";
-//			break;
-//			default:
-//			break;
-//		}
-//
-//		if (tmpName != tabName)
-//		{
-//			getGUIObjectByName (tmpName + "Window").hidden = true;
-//			getGUIObjectByName (tmpName + "Button").enabled = true;
-//		}
-//	}
-//
-//	// Make given tab visible.
-//	getGUIObjectByName (tabName + "Window").hidden = false;
-//	getGUIObjectByName (tabName + "Button").enabled = false;
-//}
-//
 //// Move the credits up the screen.
 //function updateCredits()
 //{
@@ -319,3 +301,37 @@ function blendSubmenuIntoMain(topPosition, bottomPosition)
 //		guiUnHide ("pg");
 //	}
 //}
+
+function exitGamePressed()
+{
+	closeMenu();
+	var btCaptions = [translate("Yes"), translate("No")];
+	var btCode = [Engine.Exit, null];
+	messageBox(400, 200, translate("Are you sure you want to quit 0 A.D.?"), translate("Confirmation"), 0, btCaptions, btCode);
+}
+
+function pressedScenarioEditorButton()
+{
+	closeMenu();
+	// Start Atlas
+	if (Engine.AtlasIsAvailable())
+		Engine.RestartInAtlas();
+	else
+		messageBox(400, 200, translate("The scenario editor is not available or failed to load."), translate("Error"), 2);
+}
+
+function getLobbyDisabledByBuild()
+{
+	return translate("Launch the multiplayer lobby. [DISABLED BY BUILD]");
+}
+
+function getTechnicalDetails()
+{
+	return translate("Technical Details");
+}
+
+function getManual()
+{
+	return translate("Manual");
+}
+
