@@ -58,10 +58,10 @@ const aRockSmall = "actor|geology/stone_granite_small.xml";
 const aWaterLog = "actor|props/flora/water_log.xml";
 
 // terrain + entity (for painting)
-var pPalmForest = [tForestFloor+TERRAIN_SEPARATOR+oPalm, tGrass];
-var pPineForest = [tForestFloor+TERRAIN_SEPARATOR+oPine, tGrass];
-var pPoplarForest = [tForestFloor+TERRAIN_SEPARATOR+oLombardyPoplar, tGrass];
-var pMainForest = [tForestFloor+TERRAIN_SEPARATOR+oCarob, tForestFloor+TERRAIN_SEPARATOR+oBeech, tGrass, tGrass];
+const pPalmForest = [tForestFloor+TERRAIN_SEPARATOR+oPalm, tGrass];
+const pPineForest = [tForestFloor+TERRAIN_SEPARATOR+oPine, tGrass];
+const pPoplarForest = [tForestFloor+TERRAIN_SEPARATOR+oLombardyPoplar, tGrass];
+const pMainForest = [tForestFloor+TERRAIN_SEPARATOR+oCarob, tForestFloor+TERRAIN_SEPARATOR+oBeech, tGrass, tGrass];
 
 const BUILDING_ANGlE = -PI/4;
 
@@ -71,9 +71,9 @@ log("Initializing map...");
 
 InitMap();
 
-var numPlayers = getNumPlayers();
-var mapSize = getMapSize();
-var mapArea = mapSize*mapSize;
+const numPlayers = getNumPlayers();
+const mapSize = getMapSize();
+const mapArea = mapSize*mapSize;
 
 // Create classes
 
