@@ -1,34 +1,34 @@
 RMS.LoadLibrary("rmgen");
 
-var tGrass = ["polar_snow_b"];
-var tGrassA = "polar_ice_snow";
-var tGrassB = "polar_ice";
-var tGrassC = "polar_snow_a";
-var tForestFloor = "polar_tundra_snow";
-var tCliff = "polar_snow_rocks";
-var tDirt = ["polar_snow_glacial"];
-var tRoad = "new_alpine_citytile";
-var tRoadWild = "new_alpine_citytile";
-var tShoreBlend = "alpine_shore_rocks_icy";
-var tShore = "alpine_shore_rocks";
-var tWater = "alpine_shore_rocks";
+const tSnowA = ["polar_snow_b"];
+const tSnowB = "polar_ice_snow";
+const tSnowC = "polar_ice";
+const tSnowD = "polar_snow_a";
+const tForestFloor = "polar_tundra_snow";
+const tCliff = "polar_snow_rocks";
+const tSnowE = ["polar_snow_glacial"];
+const tRoad = "new_alpine_citytile";
+const tRoadWild = "new_alpine_citytile";
+const tShoreBlend = "alpine_shore_rocks_icy";
+const tShore = "alpine_shore_rocks";
+const tWater = "alpine_shore_rocks";
 
 // gaia entities
-var oTree = "gaia/flora_tree_pine_w";
-var oStoneLarge = "gaia/geology_stonemine_alpine_quarry";
-var oStoneSmall = "gaia/geology_stone_alpine_a";
-var oMetalLarge = "gaia/geology_metal_alpine_slabs";
-var oFish = "gaia/fauna_fish";
-var oDeer = "gaia/fauna_walrus";
-var oSheep = "gaia/fauna_wolf_snow";
+const oPine = "gaia/flora_tree_pine_w";
+const oStoneLarge = "gaia/geology_stonemine_alpine_quarry";
+const oStoneSmall = "gaia/geology_stone_alpine_a";
+const oMetalLarge = "gaia/geology_metal_alpine_slabs";
+const oFish = "gaia/fauna_fish";
+const oWalrus = "gaia/fauna_walrus";
+const oWolf = "gaia/fauna_wolf_snow";
 
 // decorative props
-var aRockLarge = "actor|geology/stone_granite_med.xml";
-var aRockMedium = "actor|geology/stone_granite_med.xml";
-var aIceberg = "actor|props/special/eyecandy/iceberg.xml";
+const aRockLarge = "actor|geology/stone_granite_med.xml";
+const aRockMedium = "actor|geology/stone_granite_med.xml";
+const aIceberg = "actor|props/special/eyecandy/iceberg.xml";
 
-var pForestD = [tForestFloor + TERRAIN_SEPARATOR + oTree, tForestFloor, tForestFloor];
-var pForestP = [tForestFloor + TERRAIN_SEPARATOR + oTree, tForestFloor, tForestFloor, tForestFloor];
+const pForestD = [tForestFloor + TERRAIN_SEPARATOR + oPine, tForestFloor, tForestFloor];
+const pForestS = [tForestFloor + TERRAIN_SEPARATOR + oPine, tForestFloor, tForestFloor, tForestFloor];
 const BUILDING_ANGlE = -PI/4;
 
 // initialize map
@@ -37,9 +37,9 @@ log("Initializing map...");
 
 InitMap();
 
-var numPlayers = getNumPlayers();
-var mapSize = getMapSize();
-var mapArea = mapSize*mapSize;
+const numPlayers = getNumPlayers();
+const mapSize = getMapSize();
+const mapArea = mapSize*mapSize;
 
 // create tile classes
 
@@ -145,7 +145,7 @@ for (var i = 0; i < numPlayers; i++)
 	var tX = round(fx + tDist * cos(tAngle));
 	var tZ = round(fz + tDist * sin(tAngle));
 	group = new SimpleGroup(
-		[new SimpleObject(oTree, num, num, 0,3)],
+		[new SimpleObject(oPine, num, num, 0,3)],
 		false, clBaseResource, tX, tZ
 	);
 	createObjectGroup(group, 0, avoidClasses(clBaseResource,2));
@@ -157,9 +157,9 @@ RMS.SetProgress(15);
 // create northern sea
 var fadedistance = 8;
 
-for (ix = 0; ix < mapSize; ix++)
+for (var ix = 0; ix < mapSize; ix++)
 {
-	for (iz = 0; iz < mapSize; iz++)
+	for (var iz = 0; iz < mapSize; iz++)
 	{
 		
 		if (iz > 0.69 * mapSize)
@@ -183,9 +183,9 @@ for (ix = 0; ix < mapSize; ix++)
 log("Creating shores...");
 for (var i = 0; i < scaleByMapSize(20,120); i++)
 {
-	placer = new ClumpPlacer(scaleByMapSize(50, 70), 0.2, 0.1, 10, randFloat(0.1,0.9)*mapSize, randFloat(0.67,0.74)*mapSize);
+	placer = new ChainPlacer(1, floor(scaleByMapSize(4, 6)), floor(scaleByMapSize(16, 30)), 1, floor(randFloat(0.1,0.9)*mapSize), floor(randFloat(0.67,0.74)*mapSize));
 	var terrainPainter = new LayeredPainter(
-		[tGrass, tGrass],		// terrains
+		[tSnowA, tSnowA],		// terrains
 		[2]								// widths
 	);
 	var elevationPainter = new SmoothElevationPainter(ELEVATION_SET, 3, 3);
@@ -198,9 +198,9 @@ for (var i = 0; i < scaleByMapSize(20,120); i++)
 
 // create islands
 log("Creating islands...");
-placer = new ClumpPlacer(scaleByMapSize(40, 180), 0.2, 0.1, 1);
+placer = new ChainPlacer(1, floor(scaleByMapSize(4, 6)), floor(scaleByMapSize(16, 40)), 0.1);
 var terrainPainter = new LayeredPainter(
-	[tGrass, tGrass],		// terrains
+	[tSnowA, tSnowA],		// terrains
 	[3]								// widths
 );
 var elevationPainter = new SmoothElevationPainter(ELEVATION_SET, 3, 3);
@@ -216,7 +216,7 @@ paintTerrainBasedOnHeight(-6, 1, 1, tWater);
 // create lakes
 log("Creating lakes...");
 var numLakes = round(scaleByMapSize(1,4) * numPlayers);
-var placer = new ClumpPlacer(scaleByMapSize(100,250), 0.8, 0.1, 10);
+var placer = new ChainPlacer(1, floor(scaleByMapSize(5, 7)), floor(scaleByMapSize(20, 50)), 0.1);
 var terrainPainter = new LayeredPainter(
 	[tShoreBlend, tShore, tWater],		// terrains
 	[1,1]							// widths
@@ -225,7 +225,7 @@ var elevationPainter = new SmoothElevationPainter(ELEVATION_SET, -4, 3);
 var waterAreas = createAreas(
 	placer,
 	[terrainPainter, elevationPainter, paintClass(clWater)], 
-	avoidClasses(clPlayer, 15, clWater, 20),
+	avoidClasses(clPlayer, 20, clWater, 20),
 	numLakes
 );
 
@@ -236,17 +236,17 @@ RMS.SetProgress(45);
 
 // create hills
 log("Creating hills...");
-placer = new ClumpPlacer(scaleByMapSize(20, 150), 0.2, 0.1, 1);
+placer = new ChainPlacer(1, floor(scaleByMapSize(4, 6)), floor(scaleByMapSize(16, 40)), 0.1);
 var terrainPainter = new LayeredPainter(
-	[tCliff, tGrass],		// terrains
+	[tCliff, tSnowA],		// terrains
 	[3]								// widths
 );
 var elevationPainter = new SmoothElevationPainter(ELEVATION_SET, 25, 3);
 createAreas(
 	placer,
 	[terrainPainter, elevationPainter, paintClass(clHill)], 
-	avoidClasses(clPlayer, 12, clHill, 15, clWater, 2, clBaseResource, 2),
-	scaleByMapSize(2, 8) * numPlayers
+	avoidClasses(clPlayer, 20, clHill, 15, clWater, 2, clBaseResource, 2),
+	scaleByMapSize(1, 4) * numPlayers
 );
 
 
@@ -263,17 +263,17 @@ var numStragglers = totalTrees * (1.0 - P_FOREST);
 // create forests
 log("Creating forests...");
 var types = [
-	[[tGrass, tGrass, tGrass, tGrass, pForestD], [tGrass, tGrass, tGrass, pForestD]],
-	[[tGrass, tGrass, tGrass, tGrass, pForestP], [tGrass, tGrass, tGrass, pForestP]]
+	[[tSnowA, tSnowA, tSnowA, tSnowA, pForestD], [tSnowA, tSnowA, tSnowA, pForestD]],
+	[[tSnowA, tSnowA, tSnowA, tSnowA, pForestS], [tSnowA, tSnowA, tSnowA, pForestS]]
 ];	// some variation
 
 
-var size = numForest / (scaleByMapSize(2,8) * numPlayers);
+var size = numForest / (scaleByMapSize(3,6) * numPlayers);
 
 var num = floor(size / types.length);
 for (var i = 0; i < types.length; ++i)
 {
-	placer = new ClumpPlacer(numForest / num, 0.1, 0.1, 1);
+	placer = new ChainPlacer(1, floor(scaleByMapSize(3, 5)), numForest / (num * floor(scaleByMapSize(2,4))), 1);
 	painter = new LayeredPainter(
 		types[i],		// terrains
 		[2]											// widths
@@ -281,7 +281,7 @@ for (var i = 0; i < types.length; ++i)
 	createAreas(
 		placer,
 		[painter, paintClass(clForest)], 
-		avoidClasses(clPlayer, 12, clForest, 20, clHill, 0, clWater, 8),
+		avoidClasses(clPlayer, 20, clForest, 20, clHill, 0, clWater, 8),
 		num
 	);
 }
@@ -298,33 +298,33 @@ RMS.SetProgress(70);
 
 // create dirt patches
 log("Creating dirt patches...");
-var sizes = [scaleByMapSize(3, 9), scaleByMapSize(5, 15), scaleByMapSize(8, 24)];
+var sizes = [scaleByMapSize(3, 6), scaleByMapSize(5, 10), scaleByMapSize(8, 21)];
 for (var i = 0; i < sizes.length; i++)
 {
-	placer = new ClumpPlacer(sizes[i], 0.3, 0.06, 0.5);
+	placer = new ChainPlacer(1, floor(scaleByMapSize(3, 5)), sizes[i], 0.5);
 	painter = new LayeredPainter(
-		[tGrassC,tGrassA,tGrassB], 		// terrains
+		[tSnowD,tSnowB,tSnowC], 		// terrains
 		[2,1]															// widths
 	);
 	createAreas(
 		placer,
 		[painter, paintClass(clDirt)],
-		avoidClasses(clWater, 8, clForest, 0, clHill, 0, clPlayer, 12, clDirt, 16),
+		avoidClasses(clWater, 8, clForest, 0, clHill, 0, clPlayer, 20, clDirt, 16),
 		scaleByMapSize(20, 80)
 	);
 }
-var sizes = [scaleByMapSize(3, 9), scaleByMapSize(5, 15), scaleByMapSize(8, 24)];
+var sizes = [scaleByMapSize(2, 4), scaleByMapSize(3, 7), scaleByMapSize(5, 15)];
 for (var i = 0; i < sizes.length; i++)
 {
-	placer = new ClumpPlacer(sizes[i], 0.3, 0.06, 0.5);
+	placer = new ChainPlacer(1, floor(scaleByMapSize(3, 5)), sizes[i], 0.5);
 	painter = new LayeredPainter(
-		[tDirt,tDirt], 		// terrains
+		[tSnowE,tSnowE], 		// terrains
 		[1]															// widths
 	);
 	createAreas(
 		placer,
 		[painter, paintClass(clDirt)],
-		avoidClasses(clWater, 8, clForest, 0, clHill, 0, clPlayer, 12, clDirt, 16),
+		avoidClasses(clWater, 8, clForest, 0, clHill, 0, clPlayer, 20, clDirt, 16),
 		scaleByMapSize(20, 80)
 	);
 }
@@ -333,23 +333,23 @@ log("Creating stone mines...");
 // create large stone quarries
 group = new SimpleGroup([new SimpleObject(oStoneSmall, 0,2, 0,4), new SimpleObject(oStoneLarge, 1,1, 0,4)], true, clRock);
 createObjectGroups(group, 0,
-	avoidClasses(clWater, 3, clForest, 1, clPlayer, 10, clRock, 10, clHill, 1),
-	scaleByMapSize(4,16), 100
+	avoidClasses(clWater, 3, clForest, 1, clPlayer, 20, clRock, 10, clHill, 1),
+	scaleByMapSize(8,32), 100
 );
 
 // create small stone quarries
 group = new SimpleGroup([new SimpleObject(oStoneSmall, 2,5, 1,3)], true, clRock);
 createObjectGroups(group, 0,
-	avoidClasses(clWater, 3, clForest, 1, clPlayer, 10, clRock, 10, clHill, 1),
-	scaleByMapSize(4,16), 100
+	avoidClasses(clWater, 3, clForest, 1, clPlayer, 20, clRock, 10, clHill, 1),
+	scaleByMapSize(8,32), 100
 );
 
 log("Creating metal mines...");
 // create large metal quarries
 group = new SimpleGroup([new SimpleObject(oMetalLarge, 1,1, 0,4)], true, clMetal);
 createObjectGroups(group, 0,
-	avoidClasses(clWater, 3, clForest, 1, clPlayer, 10, clMetal, 10, clRock, 5, clHill, 1),
-	scaleByMapSize(4,16), 100
+	avoidClasses(clWater, 3, clForest, 1, clPlayer, 20, clMetal, 10, clRock, 5, clHill, 1),
+	scaleByMapSize(8,32), 100
 );
 
 
@@ -357,7 +357,7 @@ RMS.SetProgress(95);
 
 // create straggler trees
 log("Creating straggler trees...");
-var types = [oTree];	// some variation
+var types = [oPine];	// some variation
 var num = floor(numStragglers / types.length);
 for (var i = 0; i < types.length; ++i)
 {
@@ -374,11 +374,11 @@ for (var i = 0; i < types.length; ++i)
 // create deer
 log("Creating deer...");
 group = new SimpleGroup(
-	[new SimpleObject(oDeer, 5,7, 0,4)],
+	[new SimpleObject(oWalrus, 5,7, 0,4)],
 	true, clFood
 );
 createObjectGroups(group, 0,
-	avoidClasses(clWater, 3, clForest, 0, clPlayer, 10, clHill, 1, clFood, 20),
+	avoidClasses(clWater, 3, clForest, 0, clPlayer, 20, clHill, 1, clFood, 20),
 	3 * numPlayers, 50
 );
 
@@ -387,11 +387,11 @@ RMS.SetProgress(75);
 // create sheep
 log("Creating sheep...");
 group = new SimpleGroup(
-	[new SimpleObject(oSheep, 2,3, 0,2)],
+	[new SimpleObject(oWolf, 2,3, 0,2)],
 	true, clFood
 );
 createObjectGroups(group, 0,
-	avoidClasses(clWater, 3, clForest, 0, clPlayer, 10, clHill, 1, clFood, 20),
+	avoidClasses(clWater, 3, clForest, 0, clPlayer, 20, clHill, 1, clFood, 20),
 	3 * numPlayers, 50
 );
 
@@ -409,12 +409,17 @@ createObjectGroups(group, 0,
 setSunColour(0.6, 0.6, 0.6);	
 setSunElevation(PI/ 6);
 
-setWaterColour(0.0, 0.047, 0.286);				// dark majestic blue
-setWaterTint(0.471, 0.776, 0.863);				// light blue
-setWaterReflectionTint(0.0, 0.047, 0.286);
+setWaterColour(0.3, 0.347, 0.386);				// dark majestic blue
+setWaterTint(0.171, 0.236, 0.263);				// light blue
+setWaterReflectionTint(0.0, 0.047, 0.086);
 setWaterMurkiness(0.82);
 setWaterWaviness(3);
 setWaterReflectionTintStrength(0.15);
 
+setFogFactor(0.95);
+setFogThickness(0.09);
+setPPSaturation(0.28);
+setPPEffect("hdr");
+
 setSkySet("fog");
 ExportMap();
