@@ -458,7 +458,11 @@ function distanceOfPointFromLine (x1, y1, x2, y2, x3, y3)
 {
 	if (x1 == x2)
 	{
-		return x3 - x1;
+		return Math.abs(x3 - x1);
+	}
+	else if (y1 == y2)
+	{
+		return Math.abs(y3 - y1);
 	}
 	else
 	{
@@ -548,6 +552,13 @@ function createMountain(maxHeight, minRadius, maxRadius, numCircles, constraint,
 	fcc = (fcc !== undefined ? fcc : 0);
 	q = (q !== undefined ? q : []);
 	
+	// checking for an array of constraints
+	if (constraint instanceof Array)
+	{
+		var constraintArray = constraint;
+		constraint = new AndConstraint(constraintArray);
+	}
+	
 	// Preliminary bounds check
 	if (!g_Map.inMapBounds(x, z) || !constraint.allows(x, z))
 	{
