@@ -53,6 +53,16 @@ var rba9 = "actor|flora/trees/oak.xml";
 function randomizeBiome()
 {
 
+	var random_sky = randInt(1,3)
+	if (random_sky==1)
+		setSkySet("cirrus");
+	else if (random_sky ==2)
+		setSkySet("cumulus");
+	else if (random_sky ==3)
+		setSkySet("sunny");
+	setSunRotation(randFloat(0, TWO_PI));
+	setSunElevation(randFloat(PI/ 6, PI / 3));
+
 	setUnitsAmbientColour(0.57, 0.58, 0.55);
 	setTerrainAmbientColour(0.447059, 0.509804, 0.54902);
 	
@@ -77,31 +87,73 @@ function randomizeBiome()
 		setPPContrast(0.62);
 		setPPBloom(0.3);
 		
-		rbt1 = ["temp_grass_long_b"];
-		rbt2 = "temp_forestfloor_pine";
-		rbt3 = "temp_plants_bog";
+		if (randInt(2))
+		{
+			rbt1 = "alpine_grass";
+			rbt2 = "temp_forestfloor_pine";
+			rbt3 = "temp_grass_clovers_2";
+			rbt5 = "alpine_grass_a";
+			rbt6 = "alpine_grass_b";
+			rbt7 = "alpine_grass_c";
+			rbt12 = "temp_grass_mossy";
+		}
+		else
+		{
+			rbt1 = "temp_grass_long_b";
+			rbt2 = "temp_forestfloor_pine";
+			rbt3 = "temp_plants_bog";
+			rbt5 = "temp_grass_d";
+			rbt6 = "temp_grass_c";
+			rbt7 = "temp_grass_clovers_2";
+			rbt12 = "temp_grass_plants";
+		}
+		
 		rbt4 = ["temp_cliff_a", "temp_cliff_b"];
-		rbt5 = "temp_grass_d";
-		rbt6 = "temp_grass_c";
-		rbt7 = "temp_grass_clovers_2";
+		
 		rbt8 = ["temp_dirt_gravel", "temp_dirt_gravel_b"];
 		rbt9 = ["temp_dirt_gravel", "temp_dirt_gravel_b"];
 		rbt10 = "temp_road";
 		rbt11 = "temp_road_overgrown";
-		rbt12 = "temp_grass_plants";
+		
 		rbt13 = "temp_mud_plants";
 		rbt14 = "sand_grass_25";
 		rbt15 = "medit_sand_wet";
 
 		// gaia entities
-		if (randInt(1))
+		var random_trees = randInt(3);
+		
+		if (random_trees == 0)
+		{
 			rbe1 = "gaia/flora_tree_oak";
+			rbe2 = "gaia/flora_tree_oak_large";
+		}
+		else if (random_trees == 1)
+		{
+			rbe1 = "gaia/flora_tree_poplar";
+			rbe2 = "gaia/flora_tree_poplar";
+		}
 		else
+		{
 			rbe1 = "gaia/flora_tree_euro_beech";
-		rbe2 = "gaia/flora_tree_oak_large";
+			rbe2 = "gaia/flora_tree_euro_beech";
+		}
 		rbe3 = "gaia/flora_tree_apple";
-		rbe4 = "gaia/flora_tree_pine";
-		rbe5 = "gaia/flora_tree_aleppo_pine";
+		random_trees = randInt(3);
+		if (random_trees == 0)
+		{
+			rbe4 = "gaia/flora_tree_pine";
+			rbe5 = "gaia/flora_tree_aleppo_pine";
+		}
+		else if (random_trees == 1)
+		{
+			rbe4 = "gaia/flora_tree_pine";
+			rbe5 = "gaia/flora_tree_pine";
+		}
+		else
+		{
+			rbe4 = "gaia/flora_tree_aleppo_pine";
+			rbe5 = "gaia/flora_tree_aleppo_pine";
+		}
 		rbe6 = "gaia/flora_bush_berry";
 		rbe7 = "gaia/fauna_chicken";
 		rbe8 = "gaia/fauna_deer";
@@ -221,11 +273,27 @@ function randomizeBiome()
 		rbt15 = "desert_sand_wet";
 
 		// gaia entities
-		rbe1 = "gaia/flora_tree_cretan_date_palm_short";
-		rbe2 = "gaia/flora_tree_cretan_date_palm_tall";
+		if (randInt(2))
+		{
+			rbe1 = "gaia/flora_tree_cretan_date_palm_short";
+			rbe2 = "gaia/flora_tree_cretan_date_palm_tall";
+		}
+		else
+		{
+			rbe1 = "gaia/flora_tree_date_palm";
+			rbe2 = "gaia/flora_tree_date_palm";
+		}
 		rbe3 = "gaia/flora_tree_fig";
-		rbe4 = "gaia/flora_tree_tamarix";
-		rbe5 = "gaia/flora_tree_date_palm";
+		if (randInt(2))
+		{
+			rbe4 = "gaia/flora_tree_tamarix";
+			rbe5 = "gaia/flora_tree_tamarix";
+		}
+		else
+		{
+			rbe4 = "gaia/flora_tree_senegal_date_palm";
+			rbe5 = "gaia/flora_tree_senegal_date_palm";
+		}
 		rbe6 = "gaia/flora_bush_grapes";
 		rbe7 = "gaia/fauna_chicken";
 		rbe8 = "gaia/fauna_camel";
@@ -344,15 +412,45 @@ function randomizeBiome()
 		rbt15 = "medit_sand_wet";
 
 		// gaia entities
-		if (randInt(1))
+		var random_trees = randInt(3);
+		
+		if (random_trees == 0)
+		{
 			rbe1 = "gaia/flora_tree_cretan_date_palm_short";
-		else
+			rbe2 = "gaia/flora_tree_cretan_date_palm_tall";
+		}
+		else if (random_trees == 1)
+		{
 			rbe1 = "gaia/flora_tree_carob";
-		rbe2 = "gaia/flora_tree_medit_fan_palm";
-		rbe3 = "gaia/flora_tree_apple";
-		rbe4 = "gaia/flora_tree_cypress";
-		rbe5 = "gaia/flora_tree_aleppo_pine";
-		if (randInt(1))
+			rbe2 = "gaia/flora_tree_carob";
+		}
+		else
+		{
+			rbe1 = "gaia/flora_tree_medit_fan_palm";
+			rbe2 = "gaia/flora_tree_medit_fan_palm";
+		}
+		
+		if (randInt(2))
+		{
+			rbe3 = "gaia/flora_tree_apple";
+		}
+		else
+		{
+			rbe3 = "gaia/flora_tree_poplar_lombardy";
+		}
+		
+		if (randInt(2))
+		{
+			rbe4 = "gaia/flora_tree_cypress";
+			rbe5 = "gaia/flora_tree_cypress";
+		}
+		else
+		{
+			rbe4 = "gaia/flora_tree_aleppo_pine";
+			rbe5 = "gaia/flora_tree_aleppo_pine";
+		}
+		
+		if (randInt(2))
 			rbe6 = "gaia/flora_bush_berry";
 		else
 			rbe6 = "gaia/flora_bush_grapes";
@@ -496,7 +594,7 @@ function randomizeBiome()
 		rbe5 = "gaia/flora_tree_palm_tropic";
 		rbe6 = "gaia/flora_bush_berry";
 		rbe7 = "gaia/fauna_chicken";
-		rbe8 = "gaia/fauna_deer";
+		rbe8 = "gaia/fauna_peacock";
 		rbe9 = "gaia/fauna_fish";
 		rbe10 = "gaia/fauna_tiger";
 		rbe11 = "gaia/geology_stonemine_tropic_quarry";
@@ -536,8 +634,8 @@ function randomizeBiome()
 		setPPEffect("hdr");
 		
 		rbt1 = ["temp_grass_aut", "temp_grass_aut", "temp_grass_d_aut"];
-		rbt2 = "temp_forestfloor_aut";
-		rbt3 = "temp_plants_bog_aut";
+		rbt2 = "temp_plants_bog_aut";
+		rbt3 = "temp_forestfloor_aut";
 		rbt4 = ["temp_cliff_a", "temp_cliff_b"];
 		rbt5 = "temp_grass_plants_aut";
 		rbt6 = ["temp_grass_b_aut", "temp_grass_c_aut"];
@@ -553,10 +651,10 @@ function randomizeBiome()
 
 		// gaia entities
 		rbe1 = "gaia/flora_tree_euro_beech_aut";
-		rbe2 = "gaia/flora_tree_oak_aut";
+		rbe2 = "gaia/flora_tree_euro_beech_aut";
 		rbe3 = "gaia/flora_tree_pine";
-		rbe4 = "gaia/flora_tree_euro_beech_aut";
-		rbe5 = "gaia/flora_tree_euro_beech_aut";
+		rbe4 = "gaia/flora_tree_oak_aut";
+		rbe5 = "gaia/flora_tree_oak_aut";
 		rbe6 = "gaia/flora_bush_berry";
 		rbe7 = "gaia/fauna_chicken";
 		rbe8 = "gaia/fauna_deer";
