@@ -59,9 +59,13 @@ EntityGroups.prototype.add = function(ents)
 				continue;
 
 			var templateName = entState.template;
-			var template = GetTemplateData(templateName);
-			var key = template.selectionGroupName || templateName;
-			
+			var key = GetTemplateData(templateName).selectionGroupName || templateName;
+
+			// Prefix garrisoned unit's selection name with the player they belong to
+			var index = templateName.indexOf("&");
+			if (index != -1 && key.indexOf("&") == -1)
+				key = templateName.slice(0, index+1) + key;
+
 			if (this.groups[key])
 				this.groups[key] += 1;
 			else
@@ -213,6 +217,7 @@ EntitySelection.prototype.getTemplateNames = function()
  */
 EntitySelection.prototype.update = function()
 {
+	var changed = false;
 	this.checkRenamedEntities();
 	for each (var ent in this.selected)
 	{
@@ -221,9 +226,9 @@ EntitySelection.prototype.update = function()
 		// Remove deleted units
 		if (!entState)
 		{
-			delete this.selected[ent];	
+			delete this.selected[ent];
 			this.groups.removeEnt(ent);
-			this.dirty = true;
+			changed = true;
 			continue;
 		}
 
@@ -237,10 +242,12 @@ EntitySelection.prototype.update = function()
 
 			delete this.selected[ent];
 			this.groups.removeEnt(ent);
-			this.dirty = true;
+			changed = true;
 			continue;
 		}
 	}
+	if (changed)
+		this.onChange();
 };
 
 /**
@@ -314,7 +321,7 @@ EntitySelection.prototype.addList = function(ents, quiet)
 	}
 
 	this.groups.add(this.toList()); // Create Selection Groups
-	this.dirty = true;
+	this.onChange();
 };
 
 EntitySelection.prototype.removeList = function(ents)
@@ -335,7 +342,7 @@ EntitySelection.prototype.removeList = function(ents)
 	_setStatusBars(removed, false);
 	_setMotionOverlay(removed, false);
 
-	this.dirty = true;
+	this.onChange();
 };
 
 EntitySelection.prototype.reset = function()
@@ -345,13 +352,13 @@ EntitySelection.prototype.reset = function()
 	_setMotionOverlay(this.toList(), false);
 	this.selected = {};
 	this.groups.reset();
-	this.dirty = true;
+	this.onChange();
 };
 
 EntitySelection.prototype.rebuildSelection = function(renamed)
 {
 	var oldSelection = this.selected;
-	g_Selection.reset();
+	this.reset();
 
 	var toAdd = [];
 	for each (var ent in oldSelection)
@@ -403,8 +410,32 @@ EntitySelection.prototype.SetMotionDebugOverlay = function(enabled)
 	_setMotionOverlay(this.toList(), enabled);
 };
 
+EntitySelection.prototype.onChange = function()
+{
+	this.dirty = true;
+	if (this == g_Selection)
+		onSelectionChange();
+}
+
+/**
+ * Cache some quantities which depends only on selection
+ */
+
 var g_Selection = new EntitySelection();
 
+var g_canMoveIntoFormation = {};
+var g_allBuildableEntities = undefined;
+var g_allTrainableEntities = undefined;
+
+// Reset cached quantities
+function onSelectionChange()
+{
+	g_canMoveIntoFormation = {};
+	g_allBuildableEntities = undefined;
+	g_allTrainableEntities = undefined;
+}
+
+
 /**
  * EntityGroupsContainer class for managing grouped entities
  */
